@@ -1,10 +1,13 @@
 /* -----------------------------------------------------------------------------
  * Programmer(s): Cody J. Balos @ LLNL
- *                Daniel R. Reynolds @ SMU
+ *                Daniel R. Reynolds @ UMBC
  * -----------------------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2024, Lawrence Livermore National Security
+ * Copyright (c) 2025, Lawrence Livermore National Security,
+ * University of Maryland Baltimore County, and the SUNDIALS contributors.
+ * Copyright (c) 2013-2025, Lawrence Livermore National Security
  * and Southern Methodist University.
+ * Copyright (c) 2002-2013, Lawrence Livermore National Security.
  * All rights reserved.
  *
  * See the top-level LICENSE and NOTICE files for details.
@@ -45,7 +48,7 @@ class ParallelGrid
 public:
   // Constructor that creates a new ParallelGrid object.
   // [in] - the memory helper to use for allocating the MPI buffers
-  // [in,out] comm - on input, the overal MPI communicator, on output, the cartesian communicator
+  // [in,out] comm - on input, the overall MPI communicator, on output, the cartesian communicator
   // [in] a[] - an array of length 3 which defines the domain [a,b]
   // [in] b[] - an array of length 3 which defines the domain [a,b]
   // [in] npts[] - an array of length 3 which defines the number of mesh points in each dimension
@@ -508,7 +511,7 @@ public:
 
   GLOBALINT nx, ny, nz; /* number of intervals globally       */
   int nxl, nyl, nzl;    /* number of intervals locally        */
-  int npx, npy, npz;    /* numner of processes                */
+  int npx, npy, npz;    /* number of processes                */
   REAL dx, dy, dz;      /* mesh spacing                       */
   REAL ax, ay, az;      /* domain in [a, b]                   */
   REAL bx, by, bz;
