@@ -1,10 +1,13 @@
 /* -----------------------------------------------------------------------------
  * Programmer(s): David J. Gardner @ LLNL
- *                Daniel R. Reynolds @ SMU
+ *                Daniel R. Reynolds @ UMBC
  * -----------------------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2024, Lawrence Livermore National Security
+ * Copyright (c) 2025, Lawrence Livermore National Security,
+ * University of Maryland Baltimore County, and the SUNDIALS contributors.
+ * Copyright (c) 2013-2025, Lawrence Livermore National Security
  * and Southern Methodist University.
+ * Copyright (c) 2002-2013, Lawrence Livermore National Security.
  * All rights reserved.
  *
  * See the top-level LICENSE and NOTICE files for details.
@@ -41,7 +44,7 @@
  * problem is advanced in time with a diagonally implicit Runge-Kutta method
  * using an inexact Newton method paired with the PCG or SPGMR linear solver
  * using hypre's PFMG preconditioner. Several command line options are available
- * to change the problem parameters and ARKStep settings. Use the flag --help
+ * to change the problem parameters and ARKODE settings. Use the flag --help
  * for more information.
  * ---------------------------------------------------------------------------*/
 
@@ -52,6 +55,7 @@
 #include <iostream>
 #include <limits>
 #include <sstream>
+#include <string>
 
 #include "HYPRE_struct_ls.h"           // HYPRE structured grid solver interface
 #include "arkode/arkode_arkstep.h"     // access to ARKStep
@@ -61,11 +65,10 @@
 #include "sunlinsol/sunlinsol_spgmr.h" // access to SPGMR SUNLinearSolver
 
 // Macros for problem constants
-#define PI    SUN_RCONST(3.141592653589793238462643383279502884197169)
-#define ZERO  SUN_RCONST(0.0)
-#define ONE   SUN_RCONST(1.0)
-#define TWO   SUN_RCONST(2.0)
-#define EIGHT SUN_RCONST(8.0)
+#define PI   SUN_RCONST(3.141592653589793238462643383279502884197169)
+#define ZERO SUN_RCONST(0.0)
+#define ONE  SUN_RCONST(1.0)
+#define TWO  SUN_RCONST(2.0)
 
 // Macro to access (x,y) location in 1D NVector array
 #define IDX(x, y, n) ((n) * (y) + (x))
@@ -155,7 +158,7 @@ struct UserData
   sunrealtype* Ssend;
   sunrealtype* Nsend;
 
-  // Send requests for neighor exchange
+  // Send requests for neighbor exchange
   MPI_Request reqSW;
   MPI_Request reqSE;
   MPI_Request reqSS;
@@ -166,7 +169,7 @@ struct UserData
   sunrealtype atol;   // absolute tolerance
   sunrealtype hfixed; // fixed step size
   int order;          // ARKode method order
-  int controller;     // step size adaptivity method
+  string controller;  // step size adaptivity method
   int maxsteps;       // max number of steps between outputs
   bool linear;        // enable/disable linearly implicit option
 
@@ -208,7 +211,7 @@ struct UserData
                          //   3 - nonsymmetric R/B Gauss-Seidel
   HYPRE_Int pfmg_nrelax; // number of pre and post relaxation sweeps (2)
 
-  // Ouput variables
+  // Output variables
   int output;    // output level
   int nout;      // number of output times
   ofstream uout; // output file stream
@@ -312,12 +315,11 @@ static int check_flag(void* flagvalue, const string funcname, int opt);
 
 int main(int argc, char* argv[])
 {
-  int flag;                    // reusable error-checking flag
-  UserData* udata      = NULL; // user data structure
-  N_Vector u           = NULL; // vector for storing solution
-  SUNLinearSolver LS   = NULL; // linear solver memory structure
-  void* arkode_mem     = NULL; // ARKODE memory structure
-  SUNAdaptController C = NULL; // timestep adaptivity controller
+  int flag;                  // reusable error-checking flag
+  UserData* udata    = NULL; // user data structure
+  N_Vector u         = NULL; // vector for storing solution
+  SUNLinearSolver LS = NULL; // linear solver memory structure
+  void* arkode_mem   = NULL; // ARKODE memory structure
 
   // Timing variables
   double t1 = 0.0;
@@ -339,6 +341,13 @@ int main(int argc, char* argv[])
   flag = SUNContext_Create(comm_w, &ctx);
   if (check_flag(&flag, "SUNContext_Create", 1)) { return 1; }
 
+  // Initialize hypre if v2.20.0 or newer
+#if HYPRE_RELEASE_NUMBER >= 22000 || SUN_HYPRE_VERSION_MAJOR > 2 || \
+  (SUN_HYPRE_VERSION_MAJOR == 2 && SUN_HYPRE_VERSION_MINOR >= 20)
+  flag = HYPRE_Init();
+  if (check_flag(&flag, "HYPRE_Init", 1)) { return 1; }
+#endif
+
   // Set output process flag
   bool outproc = (myid == 0);
 
@@ -412,7 +421,7 @@ int main(int argc, char* argv[])
   }
 
   // --------------
-  // Setup ARKStep
+  // Setup ARKODE
   // --------------
 
   // Create integrator
@@ -420,45 +429,45 @@ int main(int argc, char* argv[])
   if (check_flag((void*)arkode_mem, "ARKStepCreate", 0)) { return 1; }
 
   // Specify tolerances
-  flag = ARKStepSStolerances(arkode_mem, udata->rtol, udata->atol);
-  if (check_flag(&flag, "ARKStepSStolerances", 1)) { return 1; }
+  flag = ARKodeSStolerances(arkode_mem, udata->rtol, udata->atol);
+  if (check_flag(&flag, "ARKodeSStolerances", 1)) { return 1; }
 
   // Attach user data
-  flag = ARKStepSetUserData(arkode_mem, (void*)udata);
-  if (check_flag(&flag, "ARKStepSetUserData", 1)) { return 1; }
+  flag = ARKodeSetUserData(arkode_mem, (void*)udata);
+  if (check_flag(&flag, "ARKodeSetUserData", 1)) { return 1; }
 
   // Attach linear solver
-  flag = ARKStepSetLinearSolver(arkode_mem, LS, NULL);
-  if (check_flag(&flag, "ARKStepSetLinearSolver", 1)) { return 1; }
+  flag = ARKodeSetLinearSolver(arkode_mem, LS, NULL);
+  if (check_flag(&flag, "ARKodeSetLinearSolver", 1)) { return 1; }
 
   if (udata->matvec)
   {
     // Attach Jacobian-vector product function
-    flag = ARKStepSetJacTimes(arkode_mem, NULL, JTimes);
-    if (check_flag(&flag, "ARKStepSetJacTimes", 1)) { return 1; }
+    flag = ARKodeSetJacTimes(arkode_mem, NULL, JTimes);
+    if (check_flag(&flag, "ARKodeSetJacTimes", 1)) { return 1; }
   }
 
   if (udata->prec)
   {
     // Attach preconditioner
-    flag = ARKStepSetPreconditioner(arkode_mem, PSetup, PSolve);
-    if (check_flag(&flag, "ARKStepSetPreconditioner", 1)) { return 1; }
+    flag = ARKodeSetPreconditioner(arkode_mem, PSetup, PSolve);
+    if (check_flag(&flag, "ARKodeSetPreconditioner", 1)) { return 1; }
 
     // Set linear solver setup frequency (update preconditioner)
-    flag = ARKStepSetLSetupFrequency(arkode_mem, udata->msbp);
-    if (check_flag(&flag, "ARKStepSetLSetupFrequency", 1)) { return 1; }
+    flag = ARKodeSetLSetupFrequency(arkode_mem, udata->msbp);
+    if (check_flag(&flag, "ARKodeSetLSetupFrequency", 1)) { return 1; }
   }
 
   // Set linear solver tolerance factor
-  flag = ARKStepSetEpsLin(arkode_mem, udata->epslin);
-  if (check_flag(&flag, "ARKStepSetEpsLin", 1)) { return 1; }
+  flag = ARKodeSetEpsLin(arkode_mem, udata->epslin);
+  if (check_flag(&flag, "ARKodeSetEpsLin", 1)) { return 1; }
 
   // Select method order
   if (udata->order > 1)
   {
     // Use an ARKode provided table
-    flag = ARKStepSetOrder(arkode_mem, udata->order);
-    if (check_flag(&flag, "ARKStepSetOrder", 1)) { return 1; }
+    flag = ARKodeSetOrder(arkode_mem, udata->order);
+    if (check_flag(&flag, "ARKodeSetOrder", 1)) { return 1; }
   }
   else
   {
@@ -482,38 +491,29 @@ int main(int argc, char* argv[])
   // Set fixed step size or adaptivity method
   if (udata->hfixed > ZERO)
   {
-    flag = ARKStepSetFixedStep(arkode_mem, udata->hfixed);
-    if (check_flag(&flag, "ARKStepSetFixedStep", 1)) { return 1; }
+    flag = ARKodeSetFixedStep(arkode_mem, udata->hfixed);
+    if (check_flag(&flag, "ARKodeSetFixedStep", 1)) { return 1; }
   }
   else
   {
-    switch (udata->controller)
-    {
-    case (ARK_ADAPT_PID): C = SUNAdaptController_PID(ctx); break;
-    case (ARK_ADAPT_PI): C = SUNAdaptController_PI(ctx); break;
-    case (ARK_ADAPT_I): C = SUNAdaptController_I(ctx); break;
-    case (ARK_ADAPT_EXP_GUS): C = SUNAdaptController_ExpGus(ctx); break;
-    case (ARK_ADAPT_IMP_GUS): C = SUNAdaptController_ImpGus(ctx); break;
-    case (ARK_ADAPT_IMEX_GUS): C = SUNAdaptController_ImExGus(ctx); break;
-    }
-    flag = ARKStepSetAdaptController(arkode_mem, C);
-    if (check_flag(&flag, "ARKStepSetAdaptController", 1)) { return 1; }
+    flag = ARKodeSetAdaptControllerByName(arkode_mem, udata->controller.c_str());
+    if (check_flag(&flag, "ARKodeSetAdaptControllerByName", 1)) { return 1; }
   }
 
   // Specify linearly implicit non-time-dependent RHS
   if (udata->linear)
   {
-    flag = ARKStepSetLinear(arkode_mem, 0);
-    if (check_flag(&flag, "ARKStepSetLinear", 1)) { return 1; }
+    flag = ARKodeSetLinear(arkode_mem, 0);
+    if (check_flag(&flag, "ARKodeSetLinear", 1)) { return 1; }
   }
 
   // Set max steps between outputs
-  flag = ARKStepSetMaxNumSteps(arkode_mem, udata->maxsteps);
-  if (check_flag(&flag, "ARKStepSetMaxNumSteps", 1)) { return 1; }
+  flag = ARKodeSetMaxNumSteps(arkode_mem, udata->maxsteps);
+  if (check_flag(&flag, "ARKodeSetMaxNumSteps", 1)) { return 1; }
 
   // Set stopping time
-  flag = ARKStepSetStopTime(arkode_mem, udata->tf);
-  if (check_flag(&flag, "ARKStepSetStopTime", 1)) { return 1; }
+  flag = ARKodeSetStopTime(arkode_mem, udata->tf);
+  if (check_flag(&flag, "ARKodeSetStopTime", 1)) { return 1; }
 
   // -----------------------
   // Loop over output times
@@ -523,7 +523,7 @@ int main(int argc, char* argv[])
   sunrealtype dTout = udata->tf / udata->nout;
   sunrealtype tout  = dTout;
 
-  // Inital output
+  // Initial output
   flag = OpenOutput(udata);
   if (check_flag(&flag, "OpenOutput", 1)) { return 1; }
 
@@ -536,8 +536,8 @@ int main(int argc, char* argv[])
     t1 = MPI_Wtime();
 
     // Evolve in time
-    flag = ARKStepEvolve(arkode_mem, tout, u, &t, ARK_NORMAL);
-    if (check_flag(&flag, "ARKStepEvolve", 1)) { break; }
+    flag = ARKodeEvolve(arkode_mem, tout, u, &t, ARK_NORMAL);
+    if (check_flag(&flag, "ARKodeEvolve", 1)) { break; }
 
     // Stop timer
     t2 = MPI_Wtime();
@@ -597,14 +597,20 @@ int main(int argc, char* argv[])
   // Clean up and return
   // --------------------
 
-  ARKStepFree(&arkode_mem); // Free integrator memory
-  SUNLinSolFree(LS);        // Free linear solver
-  N_VDestroy(u);            // Free vectors
-  FreeUserData(udata);      // Free user data
+  // Finalize hypre if v2.20.0 or newer
+#if HYPRE_RELEASE_NUMBER >= 22000 || SUN_HYPRE_VERSION_MAJOR > 2 || \
+  (SUN_HYPRE_VERSION_MAJOR == 2 && SUN_HYPRE_VERSION_MINOR >= 20)
+  flag = HYPRE_Finalize();
+  if (check_flag(&flag, "HYPRE_Finalize", 1)) { return 1; }
+#endif
+
+  ARKodeFree(&arkode_mem); // Free integrator memory
+  SUNLinSolFree(LS);       // Free linear solver
+  N_VDestroy(u);           // Free vectors
+  FreeUserData(udata);     // Free user data
   delete udata;
-  (void)SUNAdaptController_Destroy(C); // Free timestep adaptivity controller
-  SUNContext_Free(&ctx);               // Free context
-  flag = MPI_Finalize();               // Finalize MPI
+  SUNContext_Free(&ctx); // Free context
+  flag = MPI_Finalize(); // Finalize MPI
   return 0;
 }
 
@@ -1094,7 +1100,7 @@ static int PSetup(sunrealtype t, N_Vector u, N_Vector f, sunbooleantype jok,
   flag = HYPRE_StructPFMGCreate(udata->comm_c, &(udata->precond));
   if (flag != 0) { return -1; }
 
-  // Signal that the inital guess is zero
+  // Signal that the initial guess is zero
   flag = HYPRE_StructPFMGSetZeroGuess(udata->precond);
   if (flag != 0) { return -1; }
 
@@ -1167,7 +1173,7 @@ static int PSolve(sunrealtype t, N_Vector u, N_Vector f, N_Vector r, N_Vector z,
   flag = HYPRE_StructPFMGSolve(udata->precond, udata->Amatrix, udata->bvec,
                                udata->xvec);
 
-  // If a convergence error occured, clear the error and continue. For any
+  // If a convergence error occurred, clear the error and continue. For any
   // other error return with a recoverable error.
   if (flag == HYPRE_ERROR_CONV) { HYPRE_ClearError(HYPRE_ERROR_CONV); }
   else if (flag != 0) { return 1; }
@@ -1236,6 +1242,7 @@ static int SetupHypre(UserData* udata)
   flag = HYPRE_StructGridCreate(udata->comm_c, 2, &(udata->grid));
   if (flag != 0)
   {
+    cerr << "Error in HYPRE_StructGridCreate = " << flag << endl;
     FreeUserData(udata);
     return -1;
   }
@@ -1250,6 +1257,7 @@ static int SetupHypre(UserData* udata)
   flag = HYPRE_StructGridSetExtents(udata->grid, udata->ilower, udata->iupper);
   if (flag != 0)
   {
+    cerr << "Error in HYPRE_StructGridSetExtents = " << flag << endl;
     FreeUserData(udata);
     return -1;
   }
@@ -1258,6 +1266,7 @@ static int SetupHypre(UserData* udata)
   flag = HYPRE_StructGridAssemble(udata->grid);
   if (flag != 0)
   {
+    cerr << "Error in HYPRE_StructGridAssemble = " << flag << endl;
     FreeUserData(udata);
     return -1;
   }
@@ -1270,6 +1279,7 @@ static int SetupHypre(UserData* udata)
   flag = HYPRE_StructStencilCreate(2, 5, &(udata->stencil));
   if (flag != 0)
   {
+    cerr << "Error in HYPRE_StructStencilCreate = " << flag << endl;
     FreeUserData(udata);
     return -1;
   }
@@ -1282,6 +1292,7 @@ static int SetupHypre(UserData* udata)
     flag = HYPRE_StructStencilSetElement(udata->stencil, entry, offsets[entry]);
     if (flag != 0)
     {
+      cerr << "Error in HYPRE_StructStencilSetElement = " << flag << endl;
       FreeUserData(udata);
       return -1;
     }
@@ -1296,6 +1307,7 @@ static int SetupHypre(UserData* udata)
   udata->work  = new HYPRE_Real[udata->nwork];
   if (udata->work == NULL)
   {
+    cerr << "Error: unable to allocate work array" << endl;
     FreeUserData(udata);
     return -1;
   }
@@ -1307,6 +1319,7 @@ static int SetupHypre(UserData* udata)
   flag = HYPRE_StructVectorCreate(udata->comm_c, udata->grid, &(udata->xvec));
   if (flag != 0)
   {
+    cerr << "Error in HYPRE_StructVectorCreate (x) = " << flag << endl;
     FreeUserData(udata);
     return -1;
   }
@@ -1314,6 +1327,7 @@ static int SetupHypre(UserData* udata)
   flag = HYPRE_StructVectorInitialize(udata->xvec);
   if (flag != 0)
   {
+    cerr << "Error in HYPRE_StructVectorInitialize (x) = " << flag << endl;
     FreeUserData(udata);
     return -1;
   }
@@ -1325,6 +1339,7 @@ static int SetupHypre(UserData* udata)
   flag = HYPRE_StructVectorCreate(udata->comm_c, udata->grid, &(udata->bvec));
   if (flag != 0)
   {
+    cerr << "Error in HYPRE_StructVectorCreate (b) = " << flag << endl;
     FreeUserData(udata);
     return -1;
   }
@@ -1332,6 +1347,7 @@ static int SetupHypre(UserData* udata)
   flag = HYPRE_StructVectorInitialize(udata->bvec);
   if (flag != 0)
   {
+    cerr << "Error in HYPRE_StructVectorInitialize (b) = " << flag << endl;
     FreeUserData(udata);
     return -1;
   }
@@ -1345,6 +1361,7 @@ static int SetupHypre(UserData* udata)
     flag = HYPRE_StructVectorCreate(udata->comm_c, udata->grid, &(udata->vvec));
     if (flag != 0)
     {
+      cerr << "Error in HYPRE_StructVectorCreate (v) = " << flag << endl;
       FreeUserData(udata);
       return -1;
     }
@@ -1352,6 +1369,7 @@ static int SetupHypre(UserData* udata)
     flag = HYPRE_StructVectorInitialize(udata->vvec);
     if (flag != 0)
     {
+      cerr << "Error in HYPRE_StructVectorInitialize (v) = " << flag << endl;
       FreeUserData(udata);
       return -1;
     }
@@ -1363,6 +1381,7 @@ static int SetupHypre(UserData* udata)
     flag = HYPRE_StructVectorCreate(udata->comm_c, udata->grid, &(udata->Jvvec));
     if (flag != 0)
     {
+      cerr << "Error in HYPRE_StructVectorCreate (Jv) = " << flag << endl;
       FreeUserData(udata);
       return -1;
     }
@@ -1370,6 +1389,7 @@ static int SetupHypre(UserData* udata)
     flag = HYPRE_StructVectorInitialize(udata->Jvvec);
     if (flag != 0)
     {
+      cerr << "Error in HYPRE_StructVectorInitialize (Jv) = " << flag << endl;
       FreeUserData(udata);
       return -1;
     }
@@ -1383,6 +1403,7 @@ static int SetupHypre(UserData* udata)
                                   &(udata->Jmatrix));
   if (flag != 0)
   {
+    cerr << "Error in HYPRE_StructMatrixCreate (J) = " << flag << endl;
     FreeUserData(udata);
     return -1;
   }
@@ -1390,6 +1411,7 @@ static int SetupHypre(UserData* udata)
   flag = HYPRE_StructMatrixInitialize(udata->Jmatrix);
   if (flag != 0)
   {
+    cerr << "Error in HYPRE_StructMatrixInitialize (A) = " << flag << endl;
     FreeUserData(udata);
     return -1;
   }
@@ -1402,6 +1424,7 @@ static int SetupHypre(UserData* udata)
                                   &(udata->Amatrix));
   if (flag != 0)
   {
+    cerr << "Error in HYPRE_StructMatrixCreate (A) = " << flag << endl;
     FreeUserData(udata);
     return -1;
   }
@@ -1409,6 +1432,7 @@ static int SetupHypre(UserData* udata)
   flag = HYPRE_StructMatrixInitialize(udata->Amatrix);
   if (flag != 0)
   {
+    cerr << "Error in HYPRE_StructMatrixInitialize (A) = " << flag << endl;
     FreeUserData(udata);
     return -1;
   }
@@ -1431,6 +1455,7 @@ static int SetupHypre(UserData* udata)
     flag = Jac(udata);
     if (flag != 0)
     {
+      cerr << "Error in Jac = " << flag << endl;
       FreeUserData(udata);
       return -1;
     }
@@ -1438,6 +1463,7 @@ static int SetupHypre(UserData* udata)
     flag = HYPRE_StructMatrixAssemble(udata->Jmatrix);
     if (flag != 0)
     {
+      cerr << "Error in HYPRE_StructMatrixAssemble = " << flag << endl;
       FreeUserData(udata);
       return -1;
     }
@@ -1518,7 +1544,12 @@ static int Jac(UserData* udata)
     // Modify the matrix
     flag = HYPRE_StructMatrixSetBoxValues(Jmatrix, ilower, iupper, 5, entries,
                                           work);
-    if (flag != 0) { return -1; }
+    if (flag != 0)
+    {
+      cerr << "Error in HYPRE_StructMatrixSetBoxValues (interior) = " << flag
+           << endl;
+      return -1;
+    }
 
     // ----------------------------------------
     // Correct matrix values at boundary nodes
@@ -1560,7 +1591,12 @@ static int Jac(UserData* udata)
         // Modify the matrix
         flag = HYPRE_StructMatrixSetBoxValues(Jmatrix, bc_ilower, bc_iupper, 5,
                                               entries, work);
-        if (flag != 0) { return -1; }
+        if (flag != 0)
+        {
+          cerr << "Error in HYPRE_StructMatrixSetBoxValues (west bdry) = " << flag
+               << endl;
+          return -1;
+        }
       }
     }
 
@@ -1581,7 +1617,12 @@ static int Jac(UserData* udata)
         // Modify the matrix
         flag = HYPRE_StructMatrixSetBoxValues(Jmatrix, bc_ilower, bc_iupper, 5,
                                               entries, work);
-        if (flag != 0) { return -1; }
+        if (flag != 0)
+        {
+          cerr << "Error in HYPRE_StructMatrixSetBoxValues (east bdry) = " << flag
+               << endl;
+          return -1;
+        }
       }
     }
 
@@ -1602,7 +1643,12 @@ static int Jac(UserData* udata)
         // Modify the matrix
         flag = HYPRE_StructMatrixSetBoxValues(Jmatrix, bc_ilower, bc_iupper, 5,
                                               entries, work);
-        if (flag != 0) { return -1; }
+        if (flag != 0)
+        {
+          cerr << "Error in HYPRE_StructMatrixSetBoxValues (south bdry) = "
+               << flag << endl;
+          return -1;
+        }
       }
     }
 
@@ -1623,7 +1669,12 @@ static int Jac(UserData* udata)
         // Modify the matrix
         flag = HYPRE_StructMatrixSetBoxValues(Jmatrix, bc_ilower, bc_iupper, 5,
                                               entries, work);
-        if (flag != 0) { return -1; }
+        if (flag != 0)
+        {
+          cerr << "Error in HYPRE_StructMatrixSetBoxValues (north bdry) = "
+               << flag << endl;
+          return -1;
+        }
       }
     }
 
@@ -1654,7 +1705,13 @@ static int Jac(UserData* udata)
         // Modify the matrix
         flag = HYPRE_StructMatrixSetBoxValues(Jmatrix, bc_ilower, bc_iupper, 1,
                                               entry, work);
-        if (flag != 0) { return -1; }
+        if (flag != 0)
+        {
+          cerr << "Error in HYPRE_StructMatrixSetBoxValues (disconnect west "
+                  "bdry) = "
+               << flag << endl;
+          return -1;
+        }
       }
     }
 
@@ -1678,7 +1735,13 @@ static int Jac(UserData* udata)
         // Modify the matrix
         flag = HYPRE_StructMatrixSetBoxValues(Jmatrix, bc_ilower, bc_iupper, 1,
                                               entry, work);
-        if (flag != 0) { return -1; }
+        if (flag != 0)
+        {
+          cerr << "Error in HYPRE_StructMatrixSetBoxValues (disconnect east "
+                  "bdry) = "
+               << flag << endl;
+          return -1;
+        }
       }
     }
 
@@ -1702,7 +1765,13 @@ static int Jac(UserData* udata)
         // Modify the matrix
         flag = HYPRE_StructMatrixSetBoxValues(Jmatrix, bc_ilower, bc_iupper, 1,
                                               entry, work);
-        if (flag != 0) { return -1; }
+        if (flag != 0)
+        {
+          cerr << "Error in HYPRE_StructMatrixSetBoxValues (disconnect south "
+                  "bdry) = "
+               << flag << endl;
+          return -1;
+        }
       }
     }
 
@@ -1726,7 +1795,13 @@ static int Jac(UserData* udata)
         // Modify the matrix
         flag = HYPRE_StructMatrixSetBoxValues(Jmatrix, bc_ilower, bc_iupper, 1,
                                               entry, work);
-        if (flag != 0) { return -1; }
+        if (flag != 0)
+        {
+          cerr << "Error in HYPRE_StructMatrixSetBoxValues (disconnect north "
+                  "bdry) = "
+               << flag << endl;
+          return -1;
+        }
       }
     }
   }
@@ -1767,7 +1842,11 @@ static int ScaleAddI(UserData* udata, sunrealtype gamma)
   // Copy all matrix values into work array from J
   flag = HYPRE_StructMatrixGetBoxValues(udata->Jmatrix, ilower, iupper, 5,
                                         entries, work);
-  if (flag != 0) { return (flag); }
+  if (flag != 0)
+  {
+    cerr << "Error in HYPRE_StructMatrixGetBoxValues = " << flag << endl;
+    return (flag);
+  }
 
   // Scale work array by c
   for (HYPRE_Int i = 0; i < nwork; i++) { work[i] *= -gamma; }
@@ -1775,7 +1854,11 @@ static int ScaleAddI(UserData* udata, sunrealtype gamma)
   // Insert scaled values into A
   flag = HYPRE_StructMatrixSetBoxValues(udata->Amatrix, ilower, iupper, 5,
                                         entries, work);
-  if (flag != 0) { return (flag); }
+  if (flag != 0)
+  {
+    cerr << "Error in HYPRE_StructMatrixSetBoxValues = " << flag << endl;
+    return (flag);
+  }
 
   // Set first 1/5 of work array to 1
   for (HYPRE_Int i = 0; i < nwork / 5; i++) { work[i] = ONE; }
@@ -1784,7 +1867,11 @@ static int ScaleAddI(UserData* udata, sunrealtype gamma)
   HYPRE_Int entry[1] = {0};
   flag = HYPRE_StructMatrixAddToBoxValues(udata->Amatrix, ilower, iupper, 1,
                                           entry, work);
-  if (flag != 0) { return (flag); }
+  if (flag != 0)
+  {
+    cerr << "Error in HYPRE_StructMatrixAddToBoxValues = " << flag << endl;
+    return (flag);
+  }
 
   // Return success
   return 0;
@@ -2100,7 +2187,7 @@ static int InitUserData(UserData* udata)
   udata->atol       = SUN_RCONST(1.e-10); // absolute tolerance
   udata->hfixed     = ZERO;               // using adaptive step sizes
   udata->order      = 3;                  // method order
-  udata->controller = 0;                  // PID controller
+  udata->controller = "I";                // PID controller
   udata->maxsteps   = 0;                  // use default
   udata->linear     = true;               // linearly implicit problem
 
@@ -2242,10 +2329,7 @@ static int ReadInputs(int* argc, char*** argv, UserData* udata, bool outproc)
     else if (arg == "--atol") { udata->atol = stod((*argv)[arg_idx++]); }
     else if (arg == "--fixedstep") { udata->hfixed = stod((*argv)[arg_idx++]); }
     else if (arg == "--order") { udata->order = stoi((*argv)[arg_idx++]); }
-    else if (arg == "--controller")
-    {
-      udata->controller = stoi((*argv)[arg_idx++]);
-    }
+    else if (arg == "--controller") { udata->controller = (*argv)[arg_idx++]; }
     else if (arg == "--nonlinear") { udata->linear = false; }
     // Linear solver settings
     else if (arg == "--gmres") { udata->pcg = false; }
@@ -2386,7 +2470,7 @@ static void InputHelp()
   cout << "  --noforcing             : disable forcing term" << endl;
   cout << "  --tf <time>             : final time" << endl;
   cout << "  --rtol <rtol>           : relative tolerance" << endl;
-  cout << "  --atol <atol>           : absoltue tolerance" << endl;
+  cout << "  --atol <atol>           : absolute tolerance" << endl;
   cout << "  --nonlinear             : disable linearly implicit flag" << endl;
   cout << "  --order <ord>           : method order" << endl;
   cout << "  --fixedstep <step>      : used fixed step size" << endl;
@@ -2534,8 +2618,8 @@ static int OpenOutput(UserData* udata)
 static int WriteOutput(sunrealtype t, N_Vector u, UserData* udata)
 {
   int flag;
-  sunrealtype max;
-  bool outproc = (udata->myid_c == 0);
+  sunrealtype max = ZERO;
+  bool outproc    = (udata->myid_c == 0);
 
   if (udata->output > 0)
   {
@@ -2633,29 +2717,29 @@ static int OutputStats(void* arkode_mem, UserData* udata)
   int flag;
 
   // Get integrator and solver stats
-  long int nst, nst_a, netf, nfe, nfi, nni, ncfn, nli, nlcf, nsetups, nfi_ls, nJv;
-  flag = ARKStepGetNumSteps(arkode_mem, &nst);
-  if (check_flag(&flag, "ARKStepGetNumSteps", 1)) { return -1; }
-  flag = ARKStepGetNumStepAttempts(arkode_mem, &nst_a);
-  if (check_flag(&flag, "ARKStepGetNumStepAttempts", 1)) { return -1; }
-  flag = ARKStepGetNumErrTestFails(arkode_mem, &netf);
-  if (check_flag(&flag, "ARKStepGetNumErrTestFails", 1)) { return -1; }
-  flag = ARKStepGetNumRhsEvals(arkode_mem, &nfe, &nfi);
-  if (check_flag(&flag, "ARKStepGetNumRhsEvals", 1)) { return -1; }
-  flag = ARKStepGetNumNonlinSolvIters(arkode_mem, &nni);
-  if (check_flag(&flag, "ARKStepGetNumNonlinSolvIters", 1)) { return -1; }
-  flag = ARKStepGetNumNonlinSolvConvFails(arkode_mem, &ncfn);
-  if (check_flag(&flag, "ARKStepGetNumNonlinSolvConvFails", 1)) { return -1; }
-  flag = ARKStepGetNumLinIters(arkode_mem, &nli);
-  if (check_flag(&flag, "ARKStepGetNumLinIters", 1)) { return -1; }
-  flag = ARKStepGetNumLinConvFails(arkode_mem, &nlcf);
-  if (check_flag(&flag, "ARKStepGetNumLinConvFails", 1)) { return -1; }
-  flag = ARKStepGetNumLinSolvSetups(arkode_mem, &nsetups);
-  if (check_flag(&flag, "ARKStepGetNumLinSolvSetups", 1)) { return -1; }
-  flag = ARKStepGetNumLinRhsEvals(arkode_mem, &nfi_ls);
-  if (check_flag(&flag, "ARKStepGetNumLinRhsEvals", 1)) { return -1; }
-  flag = ARKStepGetNumJtimesEvals(arkode_mem, &nJv);
-  if (check_flag(&flag, "ARKStepGetNumJtimesEvals", 1)) { return -1; }
+  long int nst, nst_a, netf, nfi, nni, ncfn, nli, nlcf, nsetups, nfi_ls, nJv;
+  flag = ARKodeGetNumSteps(arkode_mem, &nst);
+  if (check_flag(&flag, "ARKodeGetNumSteps", 1)) { return -1; }
+  flag = ARKodeGetNumStepAttempts(arkode_mem, &nst_a);
+  if (check_flag(&flag, "ARKodeGetNumStepAttempts", 1)) { return -1; }
+  flag = ARKodeGetNumErrTestFails(arkode_mem, &netf);
+  if (check_flag(&flag, "ARKodeGetNumErrTestFails", 1)) { return -1; }
+  flag = ARKodeGetNumRhsEvals(arkode_mem, 1, &nfi);
+  if (check_flag(&flag, "ARKodeGetNumRhsEvals", 1)) { return -1; }
+  flag = ARKodeGetNumNonlinSolvIters(arkode_mem, &nni);
+  if (check_flag(&flag, "ARKodeGetNumNonlinSolvIters", 1)) { return -1; }
+  flag = ARKodeGetNumNonlinSolvConvFails(arkode_mem, &ncfn);
+  if (check_flag(&flag, "ARKodeGetNumNonlinSolvConvFails", 1)) { return -1; }
+  flag = ARKodeGetNumLinIters(arkode_mem, &nli);
+  if (check_flag(&flag, "ARKodeGetNumLinIters", 1)) { return -1; }
+  flag = ARKodeGetNumLinConvFails(arkode_mem, &nlcf);
+  if (check_flag(&flag, "ARKodeGetNumLinConvFails", 1)) { return -1; }
+  flag = ARKodeGetNumLinSolvSetups(arkode_mem, &nsetups);
+  if (check_flag(&flag, "ARKodeGetNumLinSolvSetups", 1)) { return -1; }
+  flag = ARKodeGetNumLinRhsEvals(arkode_mem, &nfi_ls);
+  if (check_flag(&flag, "ARKodeGetNumLinRhsEvals", 1)) { return -1; }
+  flag = ARKodeGetNumJtimesEvals(arkode_mem, &nJv);
+  if (check_flag(&flag, "ARKodeGetNumJtimesEvals", 1)) { return -1; }
 
   cout << fixed;
   cout << setprecision(6);
@@ -2684,10 +2768,10 @@ static int OutputStats(void* arkode_mem, UserData* udata)
   if (udata->prec)
   {
     long int npe, nps;
-    flag = ARKStepGetNumPrecEvals(arkode_mem, &npe);
-    if (check_flag(&flag, "ARKStepGetNumPrecEvals", 1)) { return -1; }
-    flag = ARKStepGetNumPrecSolves(arkode_mem, &nps);
-    if (check_flag(&flag, "ARKStepGetNumPrecSolves", 1)) { return -1; }
+    flag = ARKodeGetNumPrecEvals(arkode_mem, &npe);
+    if (check_flag(&flag, "ARKodeGetNumPrecEvals", 1)) { return -1; }
+    flag = ARKodeGetNumPrecSolves(arkode_mem, &nps);
+    if (check_flag(&flag, "ARKodeGetNumPrecSolves", 1)) { return -1; }
 
     cout << "  Preconditioner setups = " << npe << endl;
     cout << "  Preconditioner solves = " << nps << endl;
