@@ -1,11 +1,14 @@
 /* -----------------------------------------------------------------------------
- * Programmer(s): Rujeko Chinomona @ SMU
+ * Programmer(s): Rujeko Chinomona @ UMBC
  *                David J. Gardner @ LLNL
- *                Daniel R. Reynolds @ SMU
+ *                Daniel R. Reynolds @ UMBC
  * -----------------------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2024, Lawrence Livermore National Security
+ * Copyright (c) 2025, Lawrence Livermore National Security,
+ * University of Maryland Baltimore County, and the SUNDIALS contributors.
+ * Copyright (c) 2013-2025, Lawrence Livermore National Security
  * and Southern Methodist University.
+ * Copyright (c) 2002-2013, Lawrence Livermore National Security.
  * All rights reserved.
  *
  * See the top-level LICENSE and NOTICE files for details.
@@ -39,7 +42,7 @@
  * an inexact Newton method paired with the PCG linear solver using hypre's PFMG
  * preconditioner for the slow-implicit nonlinear solve and inexact Newton with
  * GMRES for the fast nonlinear solve.  Several command line options are
- * available to change the problem parameters and ARKStep settings. Use the flag
+ * available to change the problem parameters and ARKODE settings. Use the flag
  * --help for more information.
  * ---------------------------------------------------------------------------*/
 
@@ -50,6 +53,7 @@
 #include <iostream>
 #include <limits>
 #include <sstream>
+#include <string>
 
 #include "HYPRE_struct_ls.h"          // HYPRE structured grid solver interface
 #include "arkode/arkode_arkstep.h"    // access to ARKStep
@@ -61,11 +65,10 @@
 #include "sunlinsol/sunlinsol_spgmr.h" // access to GMRES SUNLinearSolver
 
 // Macros for problem constants
-#define PI    SUN_RCONST(3.141592653589793238462643383279502884197169)
-#define ZERO  SUN_RCONST(0.0)
-#define ONE   SUN_RCONST(1.0)
-#define TWO   SUN_RCONST(2.0)
-#define EIGHT SUN_RCONST(8.0)
+#define PI   SUN_RCONST(3.141592653589793238462643383279502884197169)
+#define ZERO SUN_RCONST(0.0)
+#define ONE  SUN_RCONST(1.0)
+#define TWO  SUN_RCONST(2.0)
 
 // Macro to access (x,y) location in 1D NVector array
 #define IDX(x, y, n) ((n) * (y) + (x))
@@ -159,7 +162,7 @@ struct UserData
   sunrealtype* Ssend;
   sunrealtype* Nsend;
 
-  // Send requests for neighor exchange
+  // Send requests for neighbor exchange
   MPI_Request reqSW;
   MPI_Request reqSE;
   MPI_Request reqSS;
@@ -172,10 +175,10 @@ struct UserData
   int sorder;       // slow method order
   int forder;       // fast ARKode method order
 
-  sunrealtype hf; // fast fixed step size
-  sunrealtype hs; // slow timestep fixed
-  int controller; // step size adaptivity method
-  int maxsteps;   // max number of steps between outputs
+  sunrealtype hf;    // fast fixed step size
+  sunrealtype hs;    // slow timestep fixed
+  string controller; // step size adaptivity method
+  int maxsteps;      // max number of steps between outputs
 
   // Linear solver and preconditioner settings
   int liniters;       // number of linear iterations
@@ -210,7 +213,7 @@ struct UserData
                          //   3 - nonsymmetric R/B Gauss-Seidel
   HYPRE_Int pfmg_nrelax; // number of pre and post relaxation sweeps (2)
 
-  // Ouput variables
+  // Output variables
   int output;    // output level
   int nout;      // number of output times
   ofstream uout; // output file streams
@@ -321,7 +324,6 @@ int main(int argc, char* argv[])
   void* inner_arkode_mem            = NULL; // ARKode memory structure
   MRIStepInnerStepper inner_stepper = NULL; // inner stepper
   MRIStepCoupling C                 = NULL; // slow coupling coefficients
-  SUNAdaptController Ctrl           = NULL; // timestep adaptivity controller
 
   // Timing variables
   double t1 = 0.0;
@@ -346,6 +348,12 @@ int main(int argc, char* argv[])
     // Create SUNDIALS context
     sundials::Context sunctx(comm_w);
 
+#if HYPRE_RELEASE_NUMBER >= 22000 || SUN_HYPRE_VERSION_MAJOR > 2 || \
+  (SUN_HYPRE_VERSION_MAJOR == 2 && SUN_HYPRE_VERSION_MINOR >= 20)
+    flag = HYPRE_Init();
+    if (check_flag(&flag, "HYPRE_Init", 1)) { return 1; }
+#endif
+
     // ------------------------------------------
     // Setup UserData and parallel decomposition
     // ------------------------------------------
@@ -413,55 +421,45 @@ int main(int argc, char* argv[])
     if (check_flag((void*)inner_arkode_mem, "ARKStepCreate", 0)) { return 1; }
 
     // Specify tolerances
-    flag = ARKStepSStolerances(inner_arkode_mem, udata.rtol, udata.atol);
-    if (check_flag(&flag, "ARKStepSStolerances", 1)) { return 1; }
+    flag = ARKodeSStolerances(inner_arkode_mem, udata.rtol, udata.atol);
+    if (check_flag(&flag, "ARKodeSStolerances", 1)) { return 1; }
 
     // Attach linear solver
-    flag = ARKStepSetLinearSolver(inner_arkode_mem, LSf, NULL);
-    if (check_flag(&flag, "ARKStepSetLinearSolver", 1)) { return 1; }
+    flag = ARKodeSetLinearSolver(inner_arkode_mem, LSf, NULL);
+    if (check_flag(&flag, "ARKodeSetLinearSolver", 1)) { return 1; }
 
     // Set linear solver tolerance factor
-    flag = ARKStepSetEpsLin(inner_arkode_mem, udata.epslin);
-    if (check_flag(&flag, "ARKStepSetEpsLin", 1)) { return 1; }
+    flag = ARKodeSetEpsLin(inner_arkode_mem, udata.epslin);
+    if (check_flag(&flag, "ARKodeSetEpsLin", 1)) { return 1; }
 
     // Use an ARKode provided table
-    flag = ARKStepSetOrder(inner_arkode_mem, udata.forder);
-    if (check_flag(&flag, "ARKStepSetOrder", 1)) { return 1; }
+    flag = ARKodeSetOrder(inner_arkode_mem, udata.forder);
+    if (check_flag(&flag, "ARKodeSetOrder", 1)) { return 1; }
 
     // Set fixed step size or adaptivity method
     if (udata.hf > ZERO)
     {
-      flag = ARKStepSetFixedStep(inner_arkode_mem, udata.hf);
-      if (check_flag(&flag, "ARKStepSetFixedStep", 1)) { return 1; }
+      flag = ARKodeSetFixedStep(inner_arkode_mem, udata.hf);
+      if (check_flag(&flag, "ARKodeSetFixedStep", 1)) { return 1; }
     }
     else
     {
-      switch (udata.controller)
-      {
-      case (ARK_ADAPT_PID): Ctrl = SUNAdaptController_PID(sunctx); break;
-      case (ARK_ADAPT_PI): Ctrl = SUNAdaptController_PI(sunctx); break;
-      case (ARK_ADAPT_I): Ctrl = SUNAdaptController_I(sunctx); break;
-      case (ARK_ADAPT_EXP_GUS): Ctrl = SUNAdaptController_ExpGus(sunctx); break;
-      case (ARK_ADAPT_IMP_GUS): Ctrl = SUNAdaptController_ImpGus(sunctx); break;
-      case (ARK_ADAPT_IMEX_GUS):
-        Ctrl = SUNAdaptController_ImExGus(sunctx);
-        break;
-      }
-      flag = ARKStepSetAdaptController(inner_arkode_mem, Ctrl);
-      if (check_flag(&flag, "ARKStepSetAdaptController", 1)) { return 1; }
+      flag = ARKodeSetAdaptControllerByName(inner_arkode_mem,
+                                            udata.controller.c_str());
+      if (check_flag(&flag, "ARKodeSetAdaptControllerByName", 1)) { return 1; }
     }
 
     // Attach user data
-    flag = ARKStepSetUserData(inner_arkode_mem, &udata);
-    if (check_flag(&flag, "ARKStepSetUserData", 1)) { return 1; }
+    flag = ARKodeSetUserData(inner_arkode_mem, &udata);
+    if (check_flag(&flag, "ARKodeSetUserData", 1)) { return 1; }
 
     // Set max steps between outputs
-    flag = ARKStepSetMaxNumSteps(inner_arkode_mem, udata.maxsteps);
-    if (check_flag(&flag, "ARKStepSetMaxNumSteps", 1)) { return 1; }
+    flag = ARKodeSetMaxNumSteps(inner_arkode_mem, udata.maxsteps);
+    if (check_flag(&flag, "ARKodeSetMaxNumSteps", 1)) { return 1; }
 
     // Create inner stepper
-    flag = ARKStepCreateMRIStepInnerStepper(inner_arkode_mem, &inner_stepper);
-    if (check_flag(&flag, "ARKStepCreateMRIStepInnerStepper", 1)) { return 1; }
+    flag = ARKodeCreateMRIStepInnerStepper(inner_arkode_mem, &inner_stepper);
+    if (check_flag(&flag, "ARKodeCreateMRIStepInnerStepper", 1)) { return 1; }
 
     // -----------------------------------------------
     // Set up MRIStep slow integrator and set options
@@ -475,27 +473,27 @@ int main(int argc, char* argv[])
     if (check_flag((void*)arkode_mem, "MRIStepCreate", 0)) { return 1; }
 
     // Specify tolerances
-    flag = MRIStepSStolerances(arkode_mem, udata.rtol, udata.atol);
-    if (check_flag(&flag, "MRIStepSStolerances", 1)) { return 1; }
+    flag = ARKodeSStolerances(arkode_mem, udata.rtol, udata.atol);
+    if (check_flag(&flag, "ARKodeSStolerances", 1)) { return 1; }
 
     // Attach linear solver
-    flag = MRIStepSetLinearSolver(arkode_mem, LS, NULL);
-    if (check_flag(&flag, "MRIStepSetLinearSolver", 1)) { return 1; }
+    flag = ARKodeSetLinearSolver(arkode_mem, LS, NULL);
+    if (check_flag(&flag, "ARKodeSetLinearSolver", 1)) { return 1; }
 
     if (udata.prectype != SUN_PREC_NONE)
     {
       // Attach preconditioner
-      flag = MRIStepSetPreconditioner(arkode_mem, PSetup, PSolve);
-      if (check_flag(&flag, "MRIStepSetPreconditioner", 1)) { return 1; }
+      flag = ARKodeSetPreconditioner(arkode_mem, PSetup, PSolve);
+      if (check_flag(&flag, "ARKodeSetPreconditioner", 1)) { return 1; }
 
       // Set max steps between linear solver (preconditioner) setup calls
-      flag = MRIStepSetLSetupFrequency(arkode_mem, udata.msbp);
-      if (check_flag(&flag, "MRIStepSetLSetupFrequency", 1)) { return 1; }
+      flag = ARKodeSetLSetupFrequency(arkode_mem, udata.msbp);
+      if (check_flag(&flag, "ARKodeSetLSetupFrequency", 1)) { return 1; }
     }
 
     // Set linear solver tolerance factor
-    flag = MRIStepSetEpsLin(arkode_mem, udata.epslin);
-    if (check_flag(&flag, "MRIStepSetEpsLin", 1)) { return 1; }
+    flag = ARKodeSetEpsLin(arkode_mem, udata.epslin);
+    if (check_flag(&flag, "ARKodeSetEpsLin", 1)) { return 1; }
 
     if (udata.sorder == 3)
     {
@@ -513,27 +511,27 @@ int main(int argc, char* argv[])
     if (check_flag(&flag, "MRIStepSetCoupling", 1)) { return 1; }
 
     // Set fixed step size
-    flag = MRIStepSetFixedStep(arkode_mem, udata.hs);
-    if (check_flag(&flag, "MRIStepSetFixedStep", 1)) { return 1; }
+    flag = ARKodeSetFixedStep(arkode_mem, udata.hs);
+    if (check_flag(&flag, "ARKodeSetFixedStep", 1)) { return 1; }
 
     // Specify linearly implicit non-time-dependent RHS
     if (udata.linear)
     {
-      flag = MRIStepSetLinear(arkode_mem, 0);
-      if (check_flag(&flag, "MRIStepSetLinear", 1)) { return 1; }
+      flag = ARKodeSetLinear(arkode_mem, 0);
+      if (check_flag(&flag, "ARKodeSetLinear", 1)) { return 1; }
     }
 
     // Attach user data
-    flag = MRIStepSetUserData(arkode_mem, &udata);
-    if (check_flag(&flag, "MRIStepSetUserData", 1)) { return 1; }
+    flag = ARKodeSetUserData(arkode_mem, &udata);
+    if (check_flag(&flag, "ARKodeSetUserData", 1)) { return 1; }
 
     // Set max steps between outputs
-    flag = MRIStepSetMaxNumSteps(arkode_mem, udata.maxsteps);
-    if (check_flag(&flag, "MRIStepSetMaxNumSteps", 1)) { return 1; }
+    flag = ARKodeSetMaxNumSteps(arkode_mem, udata.maxsteps);
+    if (check_flag(&flag, "ARKodeSetMaxNumSteps", 1)) { return 1; }
 
     // Set stopping time
-    flag = MRIStepSetStopTime(arkode_mem, udata.tf);
-    if (check_flag(&flag, "MRIStepSetStopTime", 1)) { return 1; }
+    flag = ARKodeSetStopTime(arkode_mem, udata.tf);
+    if (check_flag(&flag, "ARKodeSetStopTime", 1)) { return 1; }
 
     // -----------------------
     // Loop over output times
@@ -543,7 +541,7 @@ int main(int argc, char* argv[])
     sunrealtype dTout = udata.tf / udata.nout;
     sunrealtype tout  = dTout;
 
-    // Inital output
+    // Initial output
     flag = OpenOutput(&udata);
     if (check_flag(&flag, "OpenOutput", 1)) { return 1; }
 
@@ -556,8 +554,8 @@ int main(int argc, char* argv[])
       t1 = MPI_Wtime();
 
       // Evolve in time
-      flag = MRIStepEvolve(arkode_mem, tout, u, &t, ARK_NORMAL);
-      if (check_flag(&flag, "MRIStepEvolve", 1)) { break; }
+      flag = ARKodeEvolve(arkode_mem, tout, u, &t, ARK_NORMAL);
+      if (check_flag(&flag, "ARKodeEvolve", 1)) { break; }
 
       // Stop timer
       t2 = MPI_Wtime();
@@ -605,15 +603,21 @@ int main(int argc, char* argv[])
     // Clean up and return
     // --------------------
 
-    MRIStepFree(&arkode_mem);                 // Free slow integrator memory
-    ARKStepFree(&inner_arkode_mem);           // Free fast integrator memory
+    // Finalize hypre if v2.20.0 or newer
+#if HYPRE_RELEASE_NUMBER >= 22000 || SUN_HYPRE_VERSION_MAJOR > 2 || \
+  (SUN_HYPRE_VERSION_MAJOR == 2 && SUN_HYPRE_VERSION_MINOR >= 20)
+    flag = HYPRE_Finalize();
+    if (check_flag(&flag, "HYPRE_Finalize", 1)) { return 1; }
+#endif
+
+    ARKodeFree(&arkode_mem);                  // Free slow integrator memory
+    ARKodeFree(&inner_arkode_mem);            // Free fast integrator memory
     MRIStepInnerStepper_Free(&inner_stepper); // Free inner stepper
     MRIStepCoupling_Free(C);                  // Free coupling coefficients
     SUNLinSolFree(LS);                        // Free linear solver
     SUNLinSolFree(LSf);                       // Free linear solver
     N_VDestroy(u);                            // Free vectors
     FreeUserData(&udata);                     // Free user data
-    (void)SUNAdaptController_Destroy(Ctrl); // Free timestep adaptivity controller
   }
 
   // Finalize MPI
@@ -1365,7 +1369,7 @@ static int PSolve(sunrealtype t, N_Vector u, N_Vector f, N_Vector r, N_Vector z,
   flag = HYPRE_StructPFMGSolve(udata->precond, udata->Amatrix, udata->bvec,
                                udata->xvec);
 
-  // If a convergence error occured, clear the error and continue. For any
+  // If a convergence error occurred, clear the error and continue. For any
   // other error return with a recoverable error.
   if (flag == HYPRE_ERROR_CONV) { HYPRE_ClearError(HYPRE_ERROR_CONV); }
   else if (flag != 0) { return 1; }
@@ -1564,7 +1568,7 @@ static int HyprePFMG(UserData* udata)
     return -1;
   }
 
-  // signal that the inital guess is zero
+  // signal that the initial guess is zero
   flag = HYPRE_StructPFMGSetZeroGuess(udata->precond);
   if (flag != 0)
   {
@@ -2238,7 +2242,7 @@ static int InitUserData(UserData* udata)
 
   udata->hf         = ZERO;  // using adaptive step sizes at fast
   udata->hs         = 0.001; // slow step size
-  udata->controller = 0;     // PID controller
+  udata->controller = "I";   // PID controller
   udata->maxsteps   = 0;     // use ARKode default
 
   // Linear solver and preconditioner options
@@ -2374,10 +2378,7 @@ static int ReadInputs(int* argc, char*** argv, UserData* udata, bool outproc)
     else if (arg == "--forder") { udata->forder = stoi((*argv)[arg_idx++]); }
     else if (arg == "--hf") { udata->hf = stod((*argv)[arg_idx++]); }
     else if (arg == "--hs") { udata->hs = stod((*argv)[arg_idx++]); }
-    else if (arg == "--controller")
-    {
-      udata->controller = stoi((*argv)[arg_idx++]);
-    }
+    else if (arg == "--controller") { udata->controller = (*argv)[arg_idx++]; }
     // Linear solver settings
     else if (arg == "--liniters")
     {
@@ -2509,7 +2510,7 @@ static void InputHelp()
   cout << "  --r <r>                 : reaction coefficient" << endl;
   cout << "  --tf <time>             : final time" << endl;
   cout << "  --rtol <rtol>           : relative tolerance" << endl;
-  cout << "  --atol <atol>           : absoltue tolerance" << endl;
+  cout << "  --atol <atol>           : absolute tolerance" << endl;
   cout << "  --linear                : enable linearly implicit flag" << endl;
   cout << "  --sorder <ord>          : slow method order" << endl;
   cout << "  --forder <ord>          : fast method order" << endl;
@@ -2569,7 +2570,7 @@ static int PrintUserData(UserData* udata)
   cout << "  linear         = " << udata->linear << endl;
   cout << " --------------------------------- " << endl;
   cout << "  lin iters      = " << udata->liniters << endl;
-  cout << "  eps lins       = " << udata->epslin << endl;
+  cout << "  eps lin        = " << udata->epslin << endl;
   cout << "  prectype       = " << udata->prectype << endl;
   cout << "  msbp           = " << udata->msbp << endl;
   cout << "  pfmg_relax     = " << udata->pfmg_relax << endl;
@@ -2694,27 +2695,27 @@ static int OutputFastStats(void* arkode_mem, UserData* udata)
   int flag;
 
   // Get integrator and solver stats
-  long int nst, nst_a, netf, nfe, nfi, nni, ncfn, nli, nlcf, nsetups, nJv;
-  flag = ARKStepGetNumSteps(arkode_mem, &nst);
-  if (check_flag(&flag, "ARKStepGetNumSteps", 1)) { return -1; }
-  flag = ARKStepGetNumStepAttempts(arkode_mem, &nst_a);
-  if (check_flag(&flag, "ARKStepGetNumStepAttempts", 1)) { return -1; }
-  flag = ARKStepGetNumErrTestFails(arkode_mem, &netf);
-  if (check_flag(&flag, "ARKStepGetNumErrTestFails", 1)) { return -1; }
-  flag = ARKStepGetNumRhsEvals(arkode_mem, &nfe, &nfi);
-  if (check_flag(&flag, "ARKStepGetNumRhsEvals", 1)) { return -1; }
-  flag = ARKStepGetNumNonlinSolvIters(arkode_mem, &nni);
-  if (check_flag(&flag, "ARKStepGetNumNonlinSolvIters", 1)) { return -1; }
-  flag = ARKStepGetNumNonlinSolvConvFails(arkode_mem, &ncfn);
-  if (check_flag(&flag, "ARKStepGetNumNonlinSolvConvFails", 1)) { return -1; }
-  flag = ARKStepGetNumLinIters(arkode_mem, &nli);
-  if (check_flag(&flag, "ARKStepGetNumLinIters", 1)) { return -1; }
-  flag = ARKStepGetNumLinConvFails(arkode_mem, &nlcf);
-  if (check_flag(&flag, "ARKStepGetNumLinConvFails", 1)) { return -1; }
-  flag = ARKStepGetNumLinSolvSetups(arkode_mem, &nsetups);
-  if (check_flag(&flag, "ARKStepGetNumLinSolvSetups", 1)) { return -1; }
-  flag = ARKStepGetNumJtimesEvals(arkode_mem, &nJv);
-  if (check_flag(&flag, "ARKStepGetNumJtimesEvals", 1)) { return -1; }
+  long int nst, nst_a, netf, nfi, nni, ncfn, nli, nlcf, nsetups, nJv;
+  flag = ARKodeGetNumSteps(arkode_mem, &nst);
+  if (check_flag(&flag, "ARKodeGetNumSteps", 1)) { return -1; }
+  flag = ARKodeGetNumStepAttempts(arkode_mem, &nst_a);
+  if (check_flag(&flag, "ARKodeGetNumStepAttempts", 1)) { return -1; }
+  flag = ARKodeGetNumErrTestFails(arkode_mem, &netf);
+  if (check_flag(&flag, "ARKodeGetNumErrTestFails", 1)) { return -1; }
+  flag = ARKodeGetNumRhsEvals(arkode_mem, 1, &nfi);
+  if (check_flag(&flag, "ARKodeGetNumRhsEvals", 1)) { return -1; }
+  flag = ARKodeGetNumNonlinSolvIters(arkode_mem, &nni);
+  if (check_flag(&flag, "ARKodeGetNumNonlinSolvIters", 1)) { return -1; }
+  flag = ARKodeGetNumNonlinSolvConvFails(arkode_mem, &ncfn);
+  if (check_flag(&flag, "ARKodeGetNumNonlinSolvConvFails", 1)) { return -1; }
+  flag = ARKodeGetNumLinIters(arkode_mem, &nli);
+  if (check_flag(&flag, "ARKodeGetNumLinIters", 1)) { return -1; }
+  flag = ARKodeGetNumLinConvFails(arkode_mem, &nlcf);
+  if (check_flag(&flag, "ARKodeGetNumLinConvFails", 1)) { return -1; }
+  flag = ARKodeGetNumLinSolvSetups(arkode_mem, &nsetups);
+  if (check_flag(&flag, "ARKodeGetNumLinSolvSetups", 1)) { return -1; }
+  flag = ARKodeGetNumJtimesEvals(arkode_mem, &nJv);
+  if (check_flag(&flag, "ARKodeGetNumJtimesEvals", 1)) { return -1; }
 
   cout << fixed;
   cout << setprecision(6);
@@ -2742,10 +2743,10 @@ static int OutputFastStats(void* arkode_mem, UserData* udata)
   if (udata->prectype != SUN_PREC_NONE)
   {
     long int npe, nps;
-    flag = ARKStepGetNumPrecEvals(arkode_mem, &npe);
-    if (check_flag(&flag, "ARKStepGetNumPrecEvals", 1)) { return -1; }
-    flag = ARKStepGetNumPrecSolves(arkode_mem, &nps);
-    if (check_flag(&flag, "ARKStepGetNumPrecSolves", 1)) { return -1; }
+    flag = ARKodeGetNumPrecEvals(arkode_mem, &npe);
+    if (check_flag(&flag, "ARKodeGetNumPrecEvals", 1)) { return -1; }
+    flag = ARKodeGetNumPrecSolves(arkode_mem, &nps);
+    if (check_flag(&flag, "ARKodeGetNumPrecSolves", 1)) { return -1; }
 
     cout << "  Preconditioner setups = " << npe << endl;
     cout << "  Preconditioner solves = " << nps << endl;
@@ -2763,28 +2764,31 @@ static int OutputSlowStats(void* arkode_mem, UserData* udata)
 
   // Get integrator and solver stats
   long int nst, nfe, nfi, nni, ncfn, nli, nlcf, nsetups, nJv;
-  flag = MRIStepGetNumSteps(arkode_mem, &nst);
-  if (check_flag(&flag, "MRIStepGetNumSteps", 1)) { return -1; }
-  flag = MRIStepGetNumRhsEvals(arkode_mem, &nfe, &nfi);
-  if (check_flag(&flag, "MRIStepGetNumRhsEvals", 1)) { return -1; }
-  flag = MRIStepGetNumNonlinSolvIters(arkode_mem, &nni);
-  if (check_flag(&flag, "MRIStepGetNumNonlinSolvIters", 1)) { return -1; }
-  flag = MRIStepGetNumNonlinSolvConvFails(arkode_mem, &ncfn);
-  if (check_flag(&flag, "MRIStepGetNumNonlinSolvConvFails", 1)) { return -1; }
-  flag = MRIStepGetNumLinIters(arkode_mem, &nli);
-  if (check_flag(&flag, "MRIStepGetNumLinIters", 1)) { return -1; }
-  flag = MRIStepGetNumLinConvFails(arkode_mem, &nlcf);
-  if (check_flag(&flag, "MRIStepGetNumLinConvFails", 1)) { return -1; }
-  flag = MRIStepGetNumLinSolvSetups(arkode_mem, &nsetups);
-  if (check_flag(&flag, "MRIStepGetNumLinSolvSetups", 1)) { return -1; }
-  flag = MRIStepGetNumJtimesEvals(arkode_mem, &nJv);
-  if (check_flag(&flag, "MRIStepGetNumJtimesEvals", 1)) { return -1; }
+  flag = ARKodeGetNumSteps(arkode_mem, &nst);
+  if (check_flag(&flag, "ARKodeGetNumSteps", 1)) { return -1; }
+  flag = ARKodeGetNumRhsEvals(arkode_mem, 0, &nfe);
+  if (check_flag(&flag, "ARKodeGetNumRhsEvals", 1)) { return -1; }
+  flag = ARKodeGetNumRhsEvals(arkode_mem, 1, &nfi);
+  if (check_flag(&flag, "ARKodeGetNumRhsEvals", 1)) { return -1; }
+  flag = ARKodeGetNumNonlinSolvIters(arkode_mem, &nni);
+  if (check_flag(&flag, "ARKodeGetNumNonlinSolvIters", 1)) { return -1; }
+  flag = ARKodeGetNumNonlinSolvConvFails(arkode_mem, &ncfn);
+  if (check_flag(&flag, "ARKodeGetNumNonlinSolvConvFails", 1)) { return -1; }
+  flag = ARKodeGetNumLinIters(arkode_mem, &nli);
+  if (check_flag(&flag, "ARKodeGetNumLinIters", 1)) { return -1; }
+  flag = ARKodeGetNumLinConvFails(arkode_mem, &nlcf);
+  if (check_flag(&flag, "ARKodeGetNumLinConvFails", 1)) { return -1; }
+  flag = ARKodeGetNumLinSolvSetups(arkode_mem, &nsetups);
+  if (check_flag(&flag, "ARKodeGetNumLinSolvSetups", 1)) { return -1; }
+  flag = ARKodeGetNumJtimesEvals(arkode_mem, &nJv);
+  if (check_flag(&flag, "ARKodeGetNumJtimesEvals", 1)) { return -1; }
 
   cout << fixed;
   cout << setprecision(6);
 
   cout << "  Steps            = " << nst << endl;
-  cout << "  RHS evals        = " << nfi << endl;
+  cout << "  Fe RHS evals     = " << nfe << endl;
+  cout << "  Fi RHS evals     = " << nfi << endl;
   cout << "  NLS iters        = " << nni << endl;
   cout << "  NLS fails        = " << ncfn << endl;
   cout << "  LS iters         = " << nli << endl;
@@ -2802,10 +2806,10 @@ static int OutputSlowStats(void* arkode_mem, UserData* udata)
   if (udata->prectype != SUN_PREC_NONE)
   {
     long int npe, nps;
-    flag = MRIStepGetNumPrecEvals(arkode_mem, &npe);
-    if (check_flag(&flag, "MRIStepGetNumPrecEvals", 1)) { return -1; }
-    flag = MRIStepGetNumPrecSolves(arkode_mem, &nps);
-    if (check_flag(&flag, "MRIStepGetNumPrecSolves", 1)) { return -1; }
+    flag = ARKodeGetNumPrecEvals(arkode_mem, &npe);
+    if (check_flag(&flag, "ARKodeGetNumPrecEvals", 1)) { return -1; }
+    flag = ARKodeGetNumPrecSolves(arkode_mem, &nps);
+    if (check_flag(&flag, "ARKodeGetNumPrecSolves", 1)) { return -1; }
 
     cout << "  Preconditioner setups = " << npe << endl;
     cout << "  Preconditioner solves = " << nps << endl;
