@@ -1,11 +1,14 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 # ------------------------------------------------------------------------------
-# Programmer(s):  Daniel R. Reynolds @ SMU
+# Programmer(s):  Daniel R. Reynolds @ UMBC
 #                 David J. Gardner @ LLNL
 # ------------------------------------------------------------------------------
 # SUNDIALS Copyright Start
-# Copyright (c) 2002-2023, Lawrence Livermore National Security
+# Copyright (c) 2025, Lawrence Livermore National Security,
+# University of Maryland Baltimore County, and the SUNDIALS contributors.
+# Copyright (c) 2013-2025, Lawrence Livermore National Security
 # and Southern Methodist University.
+# Copyright (c) 2002-2013, Lawrence Livermore National Security.
 # All rights reserved.
 #
 # See the top-level LICENSE and NOTICE files for details.
@@ -28,7 +31,7 @@ import matplotlib.pyplot as plt
 # ------------------------------------------------------------------------------
 
 # read MPI root process problem info file
-infofile = 'heat2d_info.00000.txt'
+infofile = "heat2d_info.00000.txt"
 
 with open(infofile) as fn:
 
@@ -38,7 +41,7 @@ with open(infofile) as fn:
         # split line into list
         text = shlex.split(line)
 
-        # x-direction upper domian bound
+        # x-direction upper domain bound
         if "xu" in line:
             xu = float(text[1])
             continue
@@ -59,7 +62,7 @@ with open(infofile) as fn:
             continue
 
         # total number of MPI processes
-        if "np"in line:
+        if "np" in line:
             nprocs = int(text[1])
             continue
 
@@ -71,11 +74,11 @@ with open(infofile) as fn:
 # ------------------------------------------------------------------------------
 
 # load subdomain information, store in table
-subdomains = np.zeros((nprocs,4), dtype=np.int)
+subdomains = np.zeros((nprocs, 4), dtype=np.int)
 
 for i in range(nprocs):
 
-    infofile = 'heat2d_info.' + repr(i).zfill(5) + '.txt'
+    infofile = "heat2d_info." + repr(i).zfill(5) + ".txt"
 
     with open(infofile) as fn:
 
@@ -87,62 +90,62 @@ for i in range(nprocs):
 
             # x-direction starting index
             if "is" in line:
-                subdomains[i,0] = float(text[1])
+                subdomains[i, 0] = float(text[1])
                 continue
 
             # x-direction ending index
             if "ie" in line:
-                subdomains[i,1] = float(text[1])
+                subdomains[i, 1] = float(text[1])
                 continue
 
             # y-direction starting index
             if "js" in line:
-                subdomains[i,2] = float(text[1])
+                subdomains[i, 2] = float(text[1])
                 continue
 
             # y-direction ending index
             if "je" in line:
-                subdomains[i,3] = float(text[1])
+                subdomains[i, 3] = float(text[1])
                 continue
 
 # ------------------------------------------------------------------------------
 
 # check if the error was output
-fname = 'heat2d_error.00000.txt'
+fname = "heat2d_error.00000.txt"
 
 if os.path.isfile(fname):
-    plottype = ['solution', 'error']
+    plottype = ["solution", "error"]
 else:
-    plottype = ['solution']
+    plottype = ["solution"]
 
 for pt in plottype:
 
     # fill array with data
-    time   = np.zeros(nt)
+    time = np.zeros(nt)
     result = np.zeros((nt, ny, nx))
 
     for i in range(nprocs):
 
-        datafile = 'heat2d_' + pt + '.' + repr(i).zfill(5) + '.txt'
+        datafile = "heat2d_" + pt + "." + repr(i).zfill(5) + ".txt"
 
         # load data
         data = np.loadtxt(datafile, dtype=np.double)
 
-        if (np.shape(data)[0] != nt):
-            sys.exit('error: subdomain ' + i + ' has an incorrect number of time steps')
+        if np.shape(data)[0] != nt:
+            sys.exit("error: subdomain " + i + " has an incorrect number of time steps")
 
         # subdomain indices
-        istart = subdomains[i,0]
-        iend   = subdomains[i,1]
-        jstart = subdomains[i,2]
-        jend   = subdomains[i,3]
-        nxl    = iend - istart + 1
-        nyl    = jend - jstart + 1
+        istart = subdomains[i, 0]
+        iend = subdomains[i, 1]
+        jstart = subdomains[i, 2]
+        jend = subdomains[i, 3]
+        nxl = iend - istart + 1
+        nyl = jend - jstart + 1
 
         # extract data
         for i in range(nt):
-            time[i] = data[i,0]
-            result[i,jstart:jend+1,istart:iend+1] = np.reshape(data[i,1:], (nyl,nxl))
+            time[i] = data[i, 0]
+            result[i, jstart : jend + 1, istart : iend + 1] = np.reshape(data[i, 1:], (nyl, nxl))
 
     # determine extents of plots
     maxtemp = 1.1 * result.max()
@@ -151,7 +154,7 @@ for pt in plottype:
     # set x and y meshgrid objects
     xspan = np.linspace(0.0, xu, nx)
     yspan = np.linspace(0.0, yu, ny)
-    X,Y   = np.meshgrid(xspan, yspan)
+    X, Y = np.meshgrid(xspan, yspan)
 
     nxstr = repr(nx)
     nystr = repr(ny)
@@ -160,24 +163,33 @@ for pt in plottype:
     for tstep in range(nt):
 
         # set string constants for output plots, current time, mesh size
-        pname = 'heat2d_surf_' + pt + '.' + repr(tstep).zfill(3) + '.png'
-        tstr  = str(time[tstep])
+        pname = "heat2d_surf_" + pt + "." + repr(tstep).zfill(3) + ".png"
+        tstr = str(time[tstep])
 
         # plot surface and save to disk
         fig = plt.figure(1)
-        ax = fig.add_subplot(111, projection='3d')
+        ax = fig.add_subplot(111, projection="3d")
 
-        ax.plot_surface(X, Y, result[tstep,:,:], rstride=1, cstride=1,
-                        cmap=cm.jet, linewidth=0, antialiased=True, shade=True)
+        ax.plot_surface(
+            X,
+            Y,
+            result[tstep, :, :],
+            rstride=1,
+            cstride=1,
+            cmap=cm.jet,
+            linewidth=0,
+            antialiased=True,
+            shade=True,
+        )
 
-        ax.set_xlabel('x')
-        ax.set_ylabel('y')
+        ax.set_xlabel("x")
+        ax.set_ylabel("y")
         ax.set_zlim((mintemp, maxtemp))
-        ax.view_init(20,45)
-        if (pt == 'solution'):
-            title('u(x,y) at t = ' + tstr)
+        ax.view_init(20, 45)
+        if pt == "solution":
+            title("u(x,y) at t = " + tstr)
         else:
-            title('error(x,y) at t = ' + tstr)
+            title("error(x,y) at t = " + tstr)
         savefig(pname)
         plt.close()
 
