@@ -1,12 +1,15 @@
 /* -----------------------------------------------------------------------------
- * Programmer(s): Daniel R. Reynolds @ SMU
+ * Programmer(s): Daniel R. Reynolds @ UMBC
  *
  * (adapted from ark_heat2D.cpp, co-authored by Daniel Reynolds and David
  * Gardner (LLNL))
  * -----------------------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2025, Lawrence Livermore National Security
+ * Copyright (c) 2025, Lawrence Livermore National Security,
+ * University of Maryland Baltimore County, and the SUNDIALS contributors.
+ * Copyright (c) 2013-2025, Lawrence Livermore National Security
  * and Southern Methodist University.
+ * Copyright (c) 2002-2013, Lawrence Livermore National Security.
  * All rights reserved.
  *
  * See the top-level LICENSE and NOTICE files for details.
@@ -20,9 +23,6 @@
  *
  *   u_t = kx u_xx + ky u_yy + b,
  *
- * TO-DO: update this to kx(t) and ky(t), and determine the corresponding
- * changes required for b to ensure the same analytical solution.
- *
  * for t in [0, 1] and (x,y) in [0, 1]^2, with initial condition
  *
  *   u(0,x,y) = sin^2(pi x) sin^2(pi y),
@@ -61,6 +61,7 @@
 #include "nvector/nvector_serial.h" // access to the serial N_Vector
 #include "sunadaptcontroller/sunadaptcontroller_imexgus.h"
 #include "sunadaptcontroller/sunadaptcontroller_soderlind.h"
+#include "sundials/sundials_adaptcontroller.h"
 
 // Macros for problem constants
 #define PI   SUN_RCONST(3.141592653589793238462643383279502884197169)
@@ -542,7 +543,7 @@ static int InitUserData(UserData* udata)
 
   // LSRKStep options
   udata->method          = ARKODE_LSRK_RKC_2; // RKC
-  udata->eigfrequency    = 25;   // update eigenvalue at least every 20 steps
+  udata->eigfrequency    = 25;   // update eigenvalue at least every 25 steps
   udata->stage_max_limit = 1000; // allow up to 1000 stages/step
   udata->eigsafety       = SUN_RCONST(1.01); // 1% safety factor
 
@@ -642,13 +643,6 @@ static int ReadInputs(int* argc, char*** argv, UserData* udata)
       InputHelp();
       return -1;
     }
-    // Unknown input
-    else
-    {
-      cerr << "ERROR: Invalid input " << arg << endl;
-      InputHelp();
-      return -1;
-    }
   }
 
   // Recompute total number of nodes
