@@ -3,8 +3,11 @@
  *                Radu Serban @ LLNL
  * ---------------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2022, Lawrence Livermore National Security
+ * Copyright (c) 2025, Lawrence Livermore National Security,
+ * University of Maryland Baltimore County, and the SUNDIALS contributors.
+ * Copyright (c) 2013-2025, Lawrence Livermore National Security
  * and Southern Methodist University.
+ * Copyright (c) 2002-2013, Lawrence Livermore National Security.
  * All rights reserved.
  *
  * See the top-level LICENSE and NOTICE files for details.
@@ -20,7 +23,7 @@
 
 #include <sundials/sundials_nvector.h>
 
-#ifdef __cplusplus  /* wrapper to enable C++ usage */
+#ifdef __cplusplus /* wrapper to enable C++ usage */
 extern "C" {
 #endif
 
@@ -28,11 +31,11 @@ extern "C" {
  * CVDIAG return values
  * --------------------- */
 
-#define CVDIAG_SUCCESS          0
-#define CVDIAG_MEM_NULL        -1
-#define CVDIAG_LMEM_NULL       -2
-#define CVDIAG_ILL_INPUT       -3
-#define CVDIAG_MEM_FAIL        -4
+#define CVDIAG_SUCCESS   0
+#define CVDIAG_MEM_NULL  -1
+#define CVDIAG_LMEM_NULL -2
+#define CVDIAG_ILL_INPUT -3
+#define CVDIAG_MEM_FAIL  -4
 
 /* Additional last_flag values */
 
@@ -42,16 +45,16 @@ extern "C" {
 
 /* CVDiag initialization function */
 
-SUNDIALS_EXPORT int CVDiag(void *cvode_mem);
+SUNDIALS_EXPORT int CVDiag(void* cvode_mem);
 
 /* Optional output functions */
 
-SUNDIALS_EXPORT int CVDiagGetWorkSpace(void *cvode_mem, long int *lenrwLS,
-                                       long int *leniwLS);
-SUNDIALS_EXPORT int CVDiagGetNumRhsEvals(void *cvode_mem, long int *nfevalsLS);
-SUNDIALS_EXPORT int CVDiagGetLastFlag(void *cvode_mem, long int *flag);
-SUNDIALS_EXPORT char *CVDiagGetReturnFlagName(long int flag);
-
+SUNDIALS_DEPRECATED_EXPORT_MSG(
+  "Work space functions will be removed in version 8.0.0")
+int CVDiagGetWorkSpace(void* cvode_mem, long int* lenrwLS, long int* leniwLS);
+SUNDIALS_EXPORT int CVDiagGetNumRhsEvals(void* cvode_mem, long int* nfevalsLS);
+SUNDIALS_EXPORT int CVDiagGetLastFlag(void* cvode_mem, long int* flag);
+SUNDIALS_EXPORT char* CVDiagGetReturnFlagName(long int flag);
 
 #ifdef __cplusplus
 }
