@@ -1,13 +1,16 @@
 /* -----------------------------------------------------------------
- * Programmer(s): Jean M. Sexton @ SMU
+ * Programmer(s): Jean M. Sexton @ UMBC
  *                Slaven Peles @ LLNL
  * -----------------------------------------------------------------
  * Based on work by: Scott D. Cohen, Alan C. Hindmarsh, Radu Serban,
  *                   and Aaron Collier @ LLNL
  * -----------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2024, Lawrence Livermore National Security
+ * Copyright (c) 2025, Lawrence Livermore National Security,
+ * University of Maryland Baltimore County, and the SUNDIALS contributors.
+ * Copyright (c) 2013-2025, Lawrence Livermore National Security
  * and Southern Methodist University.
+ * Copyright (c) 2002-2013, Lawrence Livermore National Security.
  * All rights reserved.
  *
  * See the top-level LICENSE and NOTICE files for details.
@@ -94,10 +97,9 @@ SUNDIALS_EXPORT N_Vector_ID N_VGetVectorID_ParHyp(N_Vector v);
 SUNDIALS_EXPORT N_Vector N_VCloneEmpty_ParHyp(N_Vector w);
 SUNDIALS_EXPORT N_Vector N_VClone_ParHyp(N_Vector w);
 SUNDIALS_EXPORT void N_VDestroy_ParHyp(N_Vector v);
-SUNDIALS_EXPORT void N_VSpace_ParHyp(N_Vector v, sunindextype* lrw,
-                                     sunindextype* liw);
-SUNDIALS_EXPORT sunrealtype* N_VGetArrayPointer_ParHyp(N_Vector v);
-SUNDIALS_EXPORT void N_VSetArrayPointer_ParHyp(sunrealtype* v_data, N_Vector v);
+SUNDIALS_DEPRECATED_EXPORT_MSG(
+  "Work space functions will be removed in version 8.0.0")
+void N_VSpace_ParHyp(N_Vector v, sunindextype* lrw, sunindextype* liw);
 SUNDIALS_EXPORT MPI_Comm N_VGetCommunicator_ParHyp(N_Vector v);
 SUNDIALS_EXPORT sunindextype N_VGetLength_ParHyp(N_Vector v);
 
@@ -214,6 +216,12 @@ SUNErrCode N_VEnableLinearCombinationVectorArray_ParHyp(N_Vector v,
 SUNDIALS_EXPORT SUNErrCode N_VEnableDotProdMultiLocal_ParHyp(N_Vector v,
                                                              sunbooleantype tf);
 
+SUNDIALS_DEPRECATED_EXPORT_MSG("Not supported, use N_VGetVector_ParHyp")
+sunrealtype* N_VGetArrayPointer_ParHyp(N_Vector v);
+
+SUNDIALS_DEPRECATED_EXPORT_MSG("Not supported, use N_VGetVector_ParHyp")
+void N_VSetArrayPointer_ParHyp(sunrealtype* v_data, N_Vector v);
+
 #ifdef __cplusplus
 }
 #endif
