@@ -1,9 +1,12 @@
 /*---------------------------------------------------------------
- * Programmer(s): Daniel R. Reynolds @ SMU
+ * Programmer(s): Daniel R. Reynolds @ UMBC
  *---------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2024, Lawrence Livermore National Security
+ * Copyright (c) 2025, Lawrence Livermore National Security,
+ * University of Maryland Baltimore County, and the SUNDIALS contributors.
+ * Copyright (c) 2013-2025, Lawrence Livermore National Security
  * and Southern Methodist University.
+ * Copyright (c) 2002-2013, Lawrence Livermore National Security.
  * All rights reserved.
  *
  * See the top-level LICENSE and NOTICE files for details.
@@ -23,6 +26,7 @@
 #include <sundials/sundials_math.h>
 #include <sundials/sundials_types.h>
 
+#include "arkode/arkode.h"
 #include "arkode_impl.h"
 #include "arkode_interp_impl.h"
 
@@ -31,19 +35,19 @@
   interpolation modules
   ---------------------------------------------------------------*/
 
-int arkInterpResize(void* arkode_mem, ARKInterp interp, ARKVecResizeFn resize,
+int arkInterpResize(ARKodeMem ark_mem, ARKInterp interp, ARKVecResizeFn resize,
                     void* resize_data, sunindextype lrw_diff,
                     sunindextype liw_diff, N_Vector tmpl)
 {
   if (interp == NULL) { return (ARK_SUCCESS); }
-  return ((int)interp->ops->resize(arkode_mem, interp, resize, resize_data,
+  return ((int)interp->ops->resize(ark_mem, interp, resize, resize_data,
                                    lrw_diff, liw_diff, tmpl));
 }
 
-void arkInterpFree(void* arkode_mem, ARKInterp interp)
+void arkInterpFree(ARKodeMem ark_mem, ARKInterp interp)
 {
   if (interp == NULL) { return; }
-  interp->ops->free(arkode_mem, interp);
+  interp->ops->free(ark_mem, interp);
   return;
 }
 
@@ -54,29 +58,29 @@ void arkInterpPrintMem(ARKInterp interp, FILE* outfile)
   return;
 }
 
-int arkInterpSetDegree(void* arkode_mem, ARKInterp interp, int degree)
+int arkInterpSetDegree(ARKodeMem ark_mem, ARKInterp interp, int degree)
 {
   if (interp == NULL) { return (ARK_SUCCESS); }
-  return ((int)interp->ops->setdegree(arkode_mem, interp, degree));
+  return ((int)interp->ops->setdegree(ark_mem, interp, degree));
 }
 
-int arkInterpInit(void* arkode_mem, ARKInterp interp, sunrealtype tnew)
+int arkInterpInit(ARKodeMem ark_mem, ARKInterp interp, sunrealtype tnew)
 {
   if (interp == NULL) { return (ARK_SUCCESS); }
-  return ((int)interp->ops->init(arkode_mem, interp, tnew));
+  return ((int)interp->ops->init(ark_mem, interp, tnew));
 }
 
-int arkInterpUpdate(void* arkode_mem, ARKInterp interp, sunrealtype tnew)
+int arkInterpUpdate(ARKodeMem ark_mem, ARKInterp interp, sunrealtype tnew)
 {
   if (interp == NULL) { return (ARK_SUCCESS); }
-  return ((int)interp->ops->update(arkode_mem, interp, tnew));
+  return ((int)interp->ops->update(ark_mem, interp, tnew));
 }
 
-int arkInterpEvaluate(void* arkode_mem, ARKInterp interp, sunrealtype tau,
+int arkInterpEvaluate(ARKodeMem ark_mem, ARKInterp interp, sunrealtype tau,
                       int d, int order, N_Vector yout)
 {
   if (interp == NULL) { return (ARK_SUCCESS); }
-  return ((int)interp->ops->evaluate(arkode_mem, interp, tau, d, order, yout));
+  return ((int)interp->ops->evaluate(ark_mem, interp, tau, d, order, yout));
 }
 
 /*---------------------------------------------------------------
@@ -90,16 +94,11 @@ int arkInterpEvaluate(void* arkode_mem, ARKInterp interp, sunrealtype tau,
   cloning an input template N_Vector.  This returns a non-NULL
   structure if no errors occurred, or a NULL value otherwise.
   ---------------------------------------------------------------*/
-ARKInterp arkInterpCreate_Hermite(void* arkode_mem, int degree)
+ARKInterp arkInterpCreate_Hermite(ARKodeMem ark_mem, int degree)
 {
   ARKInterp interp;
   ARKInterpContent_Hermite content;
   ARKInterpOps ops;
-  ARKodeMem ark_mem;
-
-  /* access ARKodeMem structure */
-  if (arkode_mem == NULL) { return (NULL); }
-  ark_mem = (ARKodeMem)arkode_mem;
 
   /* check for valid degree */
   if (degree < 0 || degree > ARK_INTERP_MAX_DEGREE) { return (NULL); }
@@ -168,17 +167,11 @@ ARKInterp arkInterpCreate_Hermite(void* arkode_mem, int degree)
 
   This routine resizes the internal vectors.
   ---------------------------------------------------------------*/
-int arkInterpResize_Hermite(void* arkode_mem, ARKInterp interp,
+int arkInterpResize_Hermite(ARKodeMem ark_mem, ARKInterp interp,
                             ARKVecResizeFn resize, void* resize_data,
                             sunindextype lrw_diff, sunindextype liw_diff,
                             N_Vector y0)
 {
-  ARKodeMem ark_mem;
-
-  /* access ARKodeMem structure */
-  if (arkode_mem == NULL) { return (ARK_MEM_NULL); }
-  ark_mem = (ARKodeMem)arkode_mem;
-
   /* resize vectors */
   if (interp == NULL) { return (ARK_SUCCESS); }
 
@@ -219,14 +212,8 @@ int arkInterpResize_Hermite(void* arkode_mem, ARKInterp interp,
 
   This routine frees the Hermite ARKInterp structure.
   ---------------------------------------------------------------*/
-void arkInterpFree_Hermite(void* arkode_mem, ARKInterp interp)
+void arkInterpFree_Hermite(ARKodeMem ark_mem, ARKInterp interp)
 {
-  ARKodeMem ark_mem;
-
-  /* access ARKodeMem structure */
-  if (arkode_mem == NULL) { return; }
-  ark_mem = (ARKodeMem)arkode_mem;
-
   /* if interpolation structure is NULL, just return */
   if (interp == NULL) { return; }
 
@@ -286,11 +273,12 @@ void arkInterpPrintMem_Hermite(ARKInterp interp, FILE* outfile)
   {
     fprintf(outfile, "arkode_interp (Hermite): degree = %d\n",
             HINT_DEGREE(interp));
-    fprintf(outfile, "arkode_interp (Hermite): told = %" RSYM "\n",
+    fprintf(outfile, "arkode_interp (Hermite): told = " SUN_FORMAT_G "\n",
             HINT_TOLD(interp));
-    fprintf(outfile, "arkode_interp (Hermite): tnew = %" RSYM "\n",
+    fprintf(outfile, "arkode_interp (Hermite): tnew = " SUN_FORMAT_G "\n",
             HINT_TNEW(interp));
-    fprintf(outfile, "arkode_interp (Hermite): h = %" RSYM "\n", HINT_H(interp));
+    fprintf(outfile, "arkode_interp (Hermite): h = " SUN_FORMAT_G "\n",
+            HINT_H(interp));
 #ifdef SUNDIALS_DEBUG_PRINTVEC
     fprintf(outfile, "arkode_interp (Hermite): fold:\n");
     N_VPrintFile(HINT_FOLD(interp), outfile);
@@ -307,57 +295,27 @@ void arkInterpPrintMem_Hermite(ARKInterp interp, FILE* outfile)
 /*---------------------------------------------------------------
   arkInterpSetDegree_Hermite
 
-  This routine sets a supplied interpolation degree.  If the
-  argument is positive, then we require that
-      0 <= degree <= ARK_INTERP_MAX_DEGREE
-  and use this value as the user-specified (or default) degree.
-
-  If the argument is negative, then we assume that this has been
-  called by a time-step module to limit the interpolant degree
-  based on the temporal method order. In this case we set the
-  Hermite polynomial degree to be the minimum of (-degree),
-  ARK_INTERP_MAX_DEGREE, and the previously-set value [i.e., in
-  case the user has already specified use of a lower-degree
-  polynomial].
+  This routine sets a supplied interpolation degree which must be
+  in the range 0 <= degree <= ARK_INTERP_MAX_DEGREE.
 
   Return values:
-    ARK_MEM_NULL -- if either arkode_mem or interp are NULL
     ARK_ILL_INPUT -- if the input is outside of allowable bounds
     ARK_INTERP_FAIL -- if the interpolation module has already
        been initialized,
     ARK_SUCCESS -- successful completion.
   ---------------------------------------------------------------*/
-int arkInterpSetDegree_Hermite(void* arkode_mem, ARKInterp interp, int degree)
+int arkInterpSetDegree_Hermite(ARKodeMem ark_mem, ARKInterp interp, int degree)
 {
-  ARKodeMem ark_mem;
-
-  /* access ARKodeMem structure */
-  if (arkode_mem == NULL) { return (ARK_MEM_NULL); }
-  ark_mem = (ARKodeMem)arkode_mem;
-
-  /* if this degree is already stored, just return */
-  if (abs(degree) == HINT_DEGREE(interp)) { return (ARK_SUCCESS); }
-
-  /* on positive degree, check for allowable value and overwrite stored degree */
-  if (degree >= 0)
+  if (degree > ARK_INTERP_MAX_DEGREE || degree < 0)
   {
-    if (degree > ARK_INTERP_MAX_DEGREE)
-    {
-      arkProcessError(ark_mem, ARK_INTERP_FAIL, __LINE__, __func__, __FILE__,
-                      "Illegal degree specified.");
-      return (ARK_ILL_INPUT);
-    }
-
-    HINT_DEGREE(interp) = degree;
-    return (ARK_SUCCESS);
+    arkProcessError(ark_mem, ARK_INTERP_FAIL, __LINE__, __func__, __FILE__,
+                    "Illegal degree specified.");
+    return ARK_ILL_INPUT;
   }
 
-  /* on negative degree, check for allowable value and update stored degree */
-  degree = -degree;
-  if (degree > ARK_INTERP_MAX_DEGREE) { degree = ARK_INTERP_MAX_DEGREE; }
-  HINT_DEGREE(interp) = SUNMIN(HINT_DEGREE(interp), degree);
+  HINT_DEGREE(interp) = degree;
 
-  return (ARK_SUCCESS);
+  return ARK_SUCCESS;
 }
 
 /*---------------------------------------------------------------
@@ -370,14 +328,8 @@ int arkInterpSetDegree_Hermite(void* arkode_mem, ARKInterp interp, int degree)
   4. Calls the full RHS routine to fill fnew
   5. Copies fnew into fold
   ---------------------------------------------------------------*/
-int arkInterpInit_Hermite(void* arkode_mem, ARKInterp interp, sunrealtype tnew)
+int arkInterpInit_Hermite(ARKodeMem ark_mem, ARKInterp interp, sunrealtype tnew)
 {
-  ARKodeMem ark_mem;
-
-  /* access ARKodeMem structure */
-  if (arkode_mem == NULL) { return (ARK_MEM_NULL); }
-  ark_mem = (ARKodeMem)arkode_mem;
-
   /* initialize time values */
   HINT_TOLD(interp) = tnew;
   HINT_TNEW(interp) = tnew;
@@ -430,14 +382,9 @@ int arkInterpInit_Hermite(void* arkode_mem, ARKInterp interp, sunrealtype tnew)
   This routine copies ynew into yold, and fnew into fold, so that
   yold and fold contain the previous values.
   ---------------------------------------------------------------*/
-int arkInterpUpdate_Hermite(void* arkode_mem, ARKInterp interp, sunrealtype tnew)
+int arkInterpUpdate_Hermite(ARKodeMem ark_mem, ARKInterp interp, sunrealtype tnew)
 {
   int retval;
-  ARKodeMem ark_mem;
-
-  /* access ARKodeMem structure */
-  if (arkode_mem == NULL) { return (ARK_MEM_NULL); }
-  ark_mem = (ARKodeMem)arkode_mem;
 
   /* call full RHS if needed -- called just BEFORE the end of a step, so yn has
      NOT been updated to ycur yet */
@@ -491,7 +438,7 @@ int arkInterpUpdate_Hermite(void* arkode_mem, ARKInterp interp, sunrealtype tnew
   where h = tnew-told, i.e. values -1<tau<0 provide interpolation,
   other values result in extrapolation.
   ---------------------------------------------------------------*/
-int arkInterpEvaluate_Hermite(void* arkode_mem, ARKInterp interp,
+int arkInterpEvaluate_Hermite(ARKodeMem ark_mem, ARKInterp interp,
                               sunrealtype tau, int d, int order, N_Vector yout)
 {
   /* local variables */
@@ -500,11 +447,6 @@ int arkInterpEvaluate_Hermite(void* arkode_mem, ARKInterp interp,
   sunrealtype h, h2, h3, h4, h5;
   sunrealtype a[6];
   N_Vector X[6];
-  ARKodeMem ark_mem;
-
-  /* access ARKodeMem structure */
-  if (arkode_mem == NULL) { return (ARK_MEM_NULL); }
-  ark_mem = (ARKodeMem)arkode_mem;
 
   /* set constants */
   tau2 = tau * tau;
@@ -522,11 +464,8 @@ int arkInterpEvaluate_Hermite(void* arkode_mem, ARKInterp interp,
   q = SUNMAX(order, 0);               /* respect lower bound  */
   q = SUNMIN(q, HINT_DEGREE(interp)); /* respect max possible */
 
-#if SUNDIALS_LOGGING_LEVEL >= SUNDIALS_LOGGING_DEBUG
-  SUNLogger_QueueMsg(ARK_LOGGER, SUN_LOGLEVEL_DEBUG,
-                     "ARKODE::arkInterpEvaluate_Hermite", "interp-eval",
-                     "tau = %" RSYM ", d = %i, q = %i", tau, d, q);
-#endif
+  SUNLogDebug(ARK_LOGGER, "interp-eval",
+              "tau = " SUN_FORMAT_G ", d = %i, q = %i", tau, d, q);
 
   /* call full RHS if needed -- called just AFTER the end of a step, so yn has
      been updated to ycur */
@@ -641,7 +580,7 @@ int arkInterpEvaluate_Hermite(void* arkode_mem, ARKInterp interp,
 
     /* first, evaluate cubic interpolant at tau=-1/3 */
     tval   = -ONE / THREE;
-    retval = arkInterpEvaluate(arkode_mem, interp, tval, 0, 3, yout);
+    retval = arkInterpEvaluate(ark_mem, interp, tval, 0, 3, yout);
     if (retval != 0) { return (ARK_RHSFUNC_FAIL); }
 
     /* second, evaluate RHS at tau=-1/3, storing the result in fa */
@@ -711,7 +650,7 @@ int arkInterpEvaluate_Hermite(void* arkode_mem, ARKInterp interp,
 
     /* first, evaluate quartic interpolant at tau=-1/3 */
     tval   = -ONE / THREE;
-    retval = arkInterpEvaluate(arkode_mem, interp, tval, 0, 4, yout);
+    retval = arkInterpEvaluate(ark_mem, interp, tval, 0, 4, yout);
     if (retval != 0) { return (ARK_RHSFUNC_FAIL); }
 
     /* second, evaluate RHS at tau=-1/3, storing the result in fa */
@@ -722,7 +661,7 @@ int arkInterpEvaluate_Hermite(void* arkode_mem, ARKInterp interp,
 
     /* third, evaluate quartic interpolant at tau=-2/3 */
     tval   = -TWO / THREE;
-    retval = arkInterpEvaluate(arkode_mem, interp, tval, 0, 4, yout);
+    retval = arkInterpEvaluate(ark_mem, interp, tval, 0, 4, yout);
     if (retval != 0) { return (ARK_RHSFUNC_FAIL); }
 
     /* fourth, evaluate RHS at tau=-2/3, storing the result in fb */
@@ -855,16 +794,11 @@ int arkInterpEvaluate_Hermite(void* arkode_mem, ARKInterp interp,
   cloning an input template N_Vector.  This returns a non-NULL
   structure if no errors occurred, or a NULL value otherwise.
   ---------------------------------------------------------------*/
-ARKInterp arkInterpCreate_Lagrange(void* arkode_mem, int degree)
+ARKInterp arkInterpCreate_Lagrange(ARKodeMem ark_mem, int degree)
 {
   ARKInterp interp;
   ARKInterpContent_Lagrange content;
   ARKInterpOps ops;
-  ARKodeMem ark_mem;
-
-  /* access ARKodeMem structure */
-  if (arkode_mem == NULL) { return (NULL); }
-  ark_mem = (ARKodeMem)arkode_mem;
 
   /* check for valid degree */
   if (degree < 0 || degree > ARK_INTERP_MAX_DEGREE) { return (NULL); }
@@ -932,16 +866,12 @@ ARKInterp arkInterpCreate_Lagrange(void* arkode_mem, int degree)
 
   This routine resizes the internal vectors.
   ---------------------------------------------------------------*/
-int arkInterpResize_Lagrange(void* arkode_mem, ARKInterp I, ARKVecResizeFn resize,
-                             void* resize_data, sunindextype lrw_diff,
-                             sunindextype liw_diff, N_Vector y0)
+int arkInterpResize_Lagrange(ARKodeMem ark_mem, ARKInterp I,
+                             ARKVecResizeFn resize, void* resize_data,
+                             sunindextype lrw_diff, sunindextype liw_diff,
+                             N_Vector y0)
 {
   int i;
-  ARKodeMem ark_mem;
-
-  /* access ARKodeMem structure */
-  if (arkode_mem == NULL) { return (ARK_MEM_NULL); }
-  ark_mem = (ARKodeMem)arkode_mem;
 
   /* resize vectors */
   if (I == NULL) { return (ARK_SUCCESS); }
@@ -968,14 +898,9 @@ int arkInterpResize_Lagrange(void* arkode_mem, ARKInterp I, ARKVecResizeFn resiz
 
   This routine frees the Lagrange ARKInterp structure.
   ---------------------------------------------------------------*/
-void arkInterpFree_Lagrange(void* arkode_mem, ARKInterp I)
+void arkInterpFree_Lagrange(ARKodeMem ark_mem, ARKInterp I)
 {
   int i;
-  ARKodeMem ark_mem;
-
-  /* access ARKodeMem structure */
-  if (arkode_mem == NULL) { return; }
-  ark_mem = (ARKodeMem)arkode_mem;
 
   /* if interpolation structure is NULL, just return */
   if (I == NULL) { return; }
@@ -985,7 +910,7 @@ void arkInterpFree_Lagrange(void* arkode_mem, ARKInterp I)
   {
     if (LINT_YHIST(I) != NULL)
     {
-      for (i = 0; i < LINT_NMAX(I); i++)
+      for (i = 0; i < LINT_NMAXALLOC(I); i++)
       {
         if (LINT_YJ(I, i) != NULL)
         {
@@ -1040,7 +965,7 @@ void arkInterpPrintMem_Lagrange(ARKInterp I, FILE* outfile)
       fprintf(outfile, "arkode_interp (Lagrange): thist =");
       for (i = 0; i < LINT_NMAX(I); i++)
       {
-        fprintf(outfile, "  %" RSYM, LINT_TJ(I, i));
+        fprintf(outfile, "  " SUN_FORMAT_G, LINT_TJ(I, i));
       }
       fprintf(outfile, "\n");
     }
@@ -1069,57 +994,27 @@ void arkInterpPrintMem_Lagrange(ARKInterp I, FILE* outfile)
 /*---------------------------------------------------------------
   arkInterpSetDegree_Lagrange
 
-  This routine sets a supplied interpolation degree.  If the
-  argument is positive, then we require that
-      0 <= degree <= ARK_INTERP_MAX_DEGREE
-  and use this value as the user-specified (or default) degree.
-
-  If the argument is negative, then we assume that this has been
-  called by a time-step module to limit the interpolant degree
-  based on the temporal method order. In this case we set the
-  Lagrange polynomial degree to be the minimum of (-degree),
-  ARK_INTERP_MAX_DEGREE, and the previously-set value [i.e., in
-  case the user has already specified use of a lower-degree
-  polynomial].
+  This routine sets a supplied interpolation degree which must be
+  in the range 0 <= degree <= ARK_INTERP_MAX_DEGREE.
 
   Return values:
-    ARK_MEM_NULL -- if either arkode_mem or interp are NULL
     ARK_ILL_INPUT -- if the input is outside of allowable bounds
     ARK_INTERP_FAIL -- if the interpolation module has already
        been initialized,
     ARK_SUCCESS -- successful completion.
   ---------------------------------------------------------------*/
-int arkInterpSetDegree_Lagrange(void* arkode_mem, ARKInterp I, int degree)
+int arkInterpSetDegree_Lagrange(ARKodeMem ark_mem, ARKInterp I, int degree)
 {
-  ARKodeMem ark_mem;
-
-  /* access ARKodeMem structure */
-  if (arkode_mem == NULL) { return (ARK_MEM_NULL); }
-  ark_mem = (ARKodeMem)arkode_mem;
-
-  /* if this degree is already stored, just return */
-  if (abs(degree) + 1 == LINT_NMAX(I)) { return (ARK_SUCCESS); }
-
-  /* on positive degree, check for allowable value and overwrite stored degree */
-  if (degree >= 0)
+  if (degree > ARK_INTERP_MAX_DEGREE || degree < 0)
   {
-    if (degree > ARK_INTERP_MAX_DEGREE)
-    {
-      arkProcessError(ark_mem, ARK_INTERP_FAIL, __LINE__, __func__, __FILE__,
-                      "Illegal degree specified.");
-      return (ARK_ILL_INPUT);
-    }
-
-    LINT_NMAX(I) = degree + 1;
-    return (ARK_SUCCESS);
+    arkProcessError(ark_mem, ARK_INTERP_FAIL, __LINE__, __func__, __FILE__,
+                    "Illegal degree specified.");
+    return ARK_ILL_INPUT;
   }
 
-  /* on negative degree, check for allowable value and update stored degree */
-  degree = -degree;
-  if (degree > ARK_INTERP_MAX_DEGREE) { degree = ARK_INTERP_MAX_DEGREE; }
-  LINT_NMAX(I) = SUNMIN(LINT_NMAX(I), degree + 1);
+  LINT_NMAX(I) = degree + 1;
 
-  return (ARK_SUCCESS);
+  return ARK_SUCCESS;
 }
 
 /*---------------------------------------------------------------
@@ -1131,14 +1026,9 @@ int arkInterpSetDegree_Lagrange(void* arkode_mem, ARKInterp I, int degree)
   3. copies current (t,y) from main ARKODE memory into history
   4. updates the 'active' history counter to 1
   ---------------------------------------------------------------*/
-int arkInterpInit_Lagrange(void* arkode_mem, ARKInterp I, sunrealtype tnew)
+int arkInterpInit_Lagrange(ARKodeMem ark_mem, ARKInterp I, sunrealtype tnew)
 {
   int i;
-  ARKodeMem ark_mem;
-
-  /* access ARKodeMem structure */
-  if (arkode_mem == NULL) { return (ARK_MEM_NULL); }
-  ark_mem = (ARKodeMem)arkode_mem;
 
   /* check if storage has increased since the last init */
   if (LINT_NMAX(I) > LINT_NMAXALLOC(I))
@@ -1150,7 +1040,7 @@ int arkInterpInit_Lagrange(void* arkode_mem, ARKInterp I, sunrealtype tnew)
     }
     if (LINT_YHIST(I) != NULL)
     {
-      for (i = 0; i < LINT_NMAX(I); i++)
+      for (i = 0; i < LINT_NMAXALLOC(I); i++)
       {
         if (LINT_YJ(I, i) != NULL)
         {
@@ -1224,20 +1114,15 @@ int arkInterpInit_Lagrange(void* arkode_mem, ARKInterp I, sunrealtype tnew)
      into the first history vector
   Otherwise it just returns with success.
   ---------------------------------------------------------------*/
-int arkInterpUpdate_Lagrange(void* arkode_mem, ARKInterp I, sunrealtype tnew)
+int arkInterpUpdate_Lagrange(ARKodeMem ark_mem, ARKInterp I, sunrealtype tnew)
 {
   int i;
-  ARKodeMem ark_mem;
   sunrealtype tdiff;
   N_Vector ytmp;
   int nhist, nmax;
   sunrealtype* thist;
   N_Vector* yhist;
 
-  /* access ARKodeMem structure */
-  if (arkode_mem == NULL) { return (ARK_MEM_NULL); }
-  ark_mem = (ARKodeMem)arkode_mem;
-
   /* set readability shortcuts */
   nhist = LINT_NHIST(I);
   nmax  = LINT_NMAX(I);
@@ -1298,7 +1183,7 @@ int arkInterpUpdate_Lagrange(void* arkode_mem, ARKInterp I, sunrealtype tnew)
   fixed step sizes, otherwise the stated lower bound is only
   approximate).
   ---------------------------------------------------------------*/
-int arkInterpEvaluate_Lagrange(void* arkode_mem, ARKInterp I, sunrealtype tau,
+int arkInterpEvaluate_Lagrange(ARKodeMem ark_mem, ARKInterp I, sunrealtype tau,
                                int deriv, int degree, N_Vector yout)
 {
   /* local variables */
@@ -1306,15 +1191,10 @@ int arkInterpEvaluate_Lagrange(void* arkode_mem, ARKInterp I, sunrealtype tau,
   sunrealtype tval;
   sunrealtype a[6];
   N_Vector X[6];
-  ARKodeMem ark_mem;
   int nhist;
   sunrealtype* thist;
   N_Vector* yhist;
 
-  /* access ARKodeMem structure */
-  if (arkode_mem == NULL) { return (ARK_MEM_NULL); }
-  ark_mem = (ARKodeMem)arkode_mem;
-
   /* set readability shortcuts */
   nhist = LINT_NHIST(I);
   thist = LINT_THIST(I);
@@ -1324,11 +1204,8 @@ int arkInterpEvaluate_Lagrange(void* arkode_mem, ARKInterp I, sunrealtype tau,
   q = SUNMAX(degree, 0);    /* respect lower bound */
   q = SUNMIN(q, nhist - 1); /* respect max possible */
 
-#if SUNDIALS_LOGGING_LEVEL >= SUNDIALS_LOGGING_DEBUG
-  SUNLogger_QueueMsg(ARK_LOGGER, SUN_LOGLEVEL_DEBUG,
-                     "ARKODE::arkInterpEvaluate_Lagrange", "interp-eval",
-                     "tau = %" RSYM ", d = %i, q = %i", tau, deriv, q);
-#endif
+  SUNLogDebug(ARK_LOGGER, "interp-eval",
+              "tau = " SUN_FORMAT_G ", d = %i, q = %i", tau, deriv, q);
 
   /* error on illegal deriv */
   if ((deriv < 0) || (deriv > 3))
