@@ -1,9 +1,12 @@
 /*---------------------------------------------------------------
- * Programmer(s): Mustafa Aggul @ SMU
+ * Programmer(s): Mustafa Aggul @ UMBC
  *---------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2025, Lawrence Livermore National Security
+ * Copyright (c) 2025, Lawrence Livermore National Security,
+ * University of Maryland Baltimore County, and the SUNDIALS contributors.
+ * Copyright (c) 2013-2025, Lawrence Livermore National Security
  * and Southern Methodist University.
+ * Copyright (c) 2002-2013, Lawrence Livermore National Security.
  * All rights reserved.
  *
  * See the top-level LICENSE and NOTICE files for details.
@@ -173,6 +176,7 @@ void* lsrkStep_Create_Commons(ARKRhsFn rhs, sunrealtype t0, N_Vector y0,
   ark_mem->step_writeparameters   = lsrkStep_WriteParameters;
   ark_mem->step_free              = lsrkStep_Free;
   ark_mem->step_printmem          = lsrkStep_PrintMem;
+  ark_mem->step_setoptions        = lsrkStep_SetOptions;
   ark_mem->step_setdefaults       = lsrkStep_SetDefaults;
   ark_mem->step_getnumrhsevals    = lsrkStep_GetNumRhsEvals;
   ark_mem->step_getestlocalerrors = lsrkStep_GetEstLocalErrors;
@@ -192,15 +196,33 @@ void* lsrkStep_Create_Commons(ARKRhsFn rhs, sunrealtype t0, N_Vector y0,
   /* Copy the input parameters into ARKODE state */
   step_mem->fe = rhs;
 
+  /* Initialize spectral radius info */
+  step_mem->lambdaR             = ZERO;
+  step_mem->lambdaI             = ZERO;
+  step_mem->spectral_radius     = ZERO;
+  step_mem->spectral_radius_max = ZERO;
+  step_mem->spectral_radius_min = ZERO;
+
+  /* Initialize flags */
+  step_mem->dom_eig_update     = SUNTRUE;
+  step_mem->dom_eig_is_current = SUNFALSE;
+  step_mem->is_SSP             = SUNFALSE;
+  step_mem->init_warmup        = SUNTRUE;
+
   /* Set NULL for dom_eig_fn */
   step_mem->dom_eig_fn = NULL;
 
+  /* Set NULL for DEE */
+  step_mem->DEE = NULL;
+
   /* Initialize all the counters */
   step_mem->nfe               = 0;
+  step_mem->nfeDQ             = 0;
   step_mem->stage_max         = 0;
   step_mem->dom_eig_num_evals = 0;
   step_mem->stage_max_limit   = STAGE_MAX_LIMIT_DEFAULT;
   step_mem->dom_eig_nst       = 0;
+  step_mem->num_dee_iters     = 0;
 
   /* Initialize main ARKODE infrastructure */
   retval = arkInit(ark_mem, t0, y0, FIRST_INIT);
@@ -275,13 +297,19 @@ int lsrkStep_ReInit_Commons(void* arkode_mem, ARKRhsFn rhs, sunrealtype t0,
 
   /* Initialize all the counters, flags and stats */
   step_mem->nfe                 = 0;
+  step_mem->nfeDQ               = 0;
   step_mem->dom_eig_num_evals   = 0;
   step_mem->stage_max           = 0;
+  step_mem->lambdaR             = ZERO;
+  step_mem->lambdaI             = ZERO;
+  step_mem->spectral_radius     = ZERO;
   step_mem->spectral_radius_max = 0;
   step_mem->spectral_radius_min = 0;
   step_mem->dom_eig_nst         = 0;
+  step_mem->num_dee_iters       = 0;
   step_mem->dom_eig_update      = SUNTRUE;
   step_mem->dom_eig_is_current  = SUNFALSE;
+  step_mem->init_warmup         = SUNTRUE;
 
   return ARK_SUCCESS;
 }
@@ -323,14 +351,37 @@ int lsrkStep_Init(ARKodeMem ark_mem, SUNDIALS_MAYBE_UNUSED sunrealtype tout,
     ark_mem->e_data    = ark_mem;
   }
 
-  /* Check if user has provided dom_eig_fn */
-  if (!step_mem->is_SSP && step_mem->dom_eig_fn == NULL)
+  /* Check if user has provided dom_eig_fn or DEE */
+  if (!step_mem->is_SSP && step_mem->dom_eig_fn == NULL && step_mem->DEE == NULL)
   {
-    arkProcessError(ark_mem, ARK_DOMEIG_FAIL, __LINE__, __func__,
-                    __FILE__, "STS methods require a user provided dominant eigenvalue function");
+    arkProcessError(ark_mem, ARK_DOMEIG_FAIL, __LINE__, __func__, __FILE__,
+                    "STS methods require either a user provided dominant "
+                    "eigenvalue function or a SUNDomEigEstimator");
     return ARK_DOMEIG_FAIL;
   }
 
+  /* Initialize the DEE */
+  if (step_mem->DEE != NULL)
+  {
+    retval = SUNDomEigEstimator_Initialize(step_mem->DEE);
+    if (retval != SUN_SUCCESS)
+    {
+      arkProcessError(ark_mem, ARK_DEE_FAIL, __LINE__, __func__, __FILE__,
+                      "SUNDomEigEstimator_Initialize failed");
+      return ARK_DEE_FAIL;
+    }
+
+    /* Set number of DEE preprocessing iterations for the initial estimate */
+    retval = SUNDomEigEstimator_SetNumPreprocessIters(step_mem->DEE,
+                                                      step_mem->num_init_warmups);
+    if (retval != SUN_SUCCESS)
+    {
+      arkProcessError(ark_mem, ARK_DEE_FAIL, __LINE__, __func__, __FILE__,
+                      "SUNDomEigEstimator_SetNumPreprocessIters failed");
+      return ARK_DEE_FAIL;
+    }
+  }
+
   /* Allocate reusable arrays for fused vector interface */
   if (step_mem->cvals == NULL)
   {
@@ -2070,9 +2121,19 @@ void lsrkStep_PrintMem(ARKodeMem ark_mem, FILE* outfile)
             step_mem->stage_max_limit);
     fprintf(outfile, "LSRKStep: dom_eig_freq          = %li\n",
             step_mem->dom_eig_freq);
+    fprintf(outfile, "LSRKStep: num_init_warmups      = %i\n",
+            step_mem->num_init_warmups);
+    fprintf(outfile, "LSRKStep: num_warmups           = %i\n",
+            step_mem->num_warmups);
 
     /* output long integer quantities */
     fprintf(outfile, "LSRKStep: nfe                   = %li\n", step_mem->nfe);
+    if (step_mem->DEE != NULL)
+    {
+      fprintf(outfile, "LSRKStep: nfeDQ               = %li\n", step_mem->nfeDQ);
+      fprintf(outfile, "LSRKStep: num_iters           = %li\n",
+              step_mem->num_dee_iters);
+    }
     fprintf(outfile, "LSRKStep: dom_eig_num_evals     = %li\n",
             step_mem->dom_eig_num_evals);
 
@@ -2096,6 +2157,17 @@ void lsrkStep_PrintMem(ARKodeMem ark_mem, FILE* outfile)
             step_mem->dom_eig_update);
     fprintf(outfile, "LSRKStep: dom_eig_is_current    = %d\n",
             step_mem->dom_eig_is_current);
+
+    if (step_mem->DEE != NULL)
+    {
+      retval = SUNDomEigEstimator_Write(step_mem->DEE, outfile);
+      if (retval != SUN_SUCCESS)
+      {
+        arkProcessError(ark_mem, ARK_DEE_FAIL, __LINE__, __func__, __FILE__,
+                        "SUNDomEigEstimator_Write failed");
+        return;
+      }
+    }
   }
   else
   {
@@ -2194,15 +2266,63 @@ int lsrkStep_ComputeNewDomEig(ARKodeMem ark_mem, ARKodeLSRKStepMem step_mem)
 {
   int retval = SUN_SUCCESS;
 
-  retval = step_mem->dom_eig_fn(ark_mem->tn, ark_mem->ycur, ark_mem->fn,
-                                &step_mem->lambdaR, &step_mem->lambdaI,
-                                ark_mem->user_data, ark_mem->tempv1,
-                                ark_mem->tempv2, ark_mem->tempv3);
-  step_mem->dom_eig_num_evals++;
-  if (retval != ARK_SUCCESS)
+  if (step_mem->DEE != NULL)
+  {
+    retval = SUNDomEigEstimator_Estimate(step_mem->DEE, &step_mem->lambdaR,
+                                         &step_mem->lambdaI);
+    step_mem->dom_eig_num_evals++;
+    if (retval != SUN_SUCCESS)
+    {
+      arkProcessError(ark_mem, ARK_DEE_FAIL, __LINE__, __func__, __FILE__,
+                      "SUNDomEigEstimator_Estimate failed");
+      return ARK_DEE_FAIL;
+    }
+
+    long int num_iters;
+    retval = SUNDomEigEstimator_GetNumIters(step_mem->DEE, &num_iters);
+    if (retval != SUN_SUCCESS)
+    {
+      arkProcessError(ark_mem, ARK_DEE_FAIL, __LINE__, __func__, __FILE__,
+                      "SUNDomEigEstimator_GetNumIters failed");
+      return ARK_DEE_FAIL;
+    }
+    step_mem->num_dee_iters += num_iters;
+
+    /* After the first call to SUNDomEigEstimator_Estimate, the number of warmups is set to
+       num_warmups, this allows the successive calls to
+       SUNDomEigEstimator_Estimate to use a diffirent number of warmups. */
+    if (step_mem->init_warmup)
+    {
+      retval = SUNDomEigEstimator_SetNumPreprocessIters(step_mem->DEE,
+                                                        step_mem->num_warmups);
+      if (retval != SUN_SUCCESS)
+      {
+        arkProcessError(ark_mem, ARK_DEE_FAIL, __LINE__, __func__, __FILE__,
+                        "SUNDomEigEstimator_SetNumPreprocessIters failed");
+        return ARK_DEE_FAIL;
+      }
+      step_mem->init_warmup = SUNFALSE;
+    }
+  }
+  else if (step_mem->dom_eig_fn != NULL)
+  {
+    retval = step_mem->dom_eig_fn(ark_mem->tn, ark_mem->ycur, ark_mem->fn,
+                                  &step_mem->lambdaR, &step_mem->lambdaI,
+                                  ark_mem->user_data, ark_mem->tempv1,
+                                  ark_mem->tempv2, ark_mem->tempv3);
+    step_mem->dom_eig_num_evals++;
+    if (retval != ARK_SUCCESS)
+    {
+      arkProcessError(ark_mem, ARK_DOMEIG_FAIL, __LINE__, __func__, __FILE__,
+                      "Unable to estimate the dominant eigenvalue");
+      return ARK_DOMEIG_FAIL;
+    }
+  }
+  else
   {
     arkProcessError(ark_mem, ARK_DOMEIG_FAIL, __LINE__, __func__, __FILE__,
-                    "Unable to estimate the dominant eigenvalue");
+                    "Unable to estimate the dominant eigenvalue: Either a user "
+                    "provided function or a SUNDomEigEstimator is required");
     return ARK_DOMEIG_FAIL;
   }
 
@@ -2244,6 +2364,78 @@ int lsrkStep_ComputeNewDomEig(ARKodeMem ark_mem, ARKodeLSRKStepMem step_mem)
   return retval;
 }
 
+/*---------------------------------------------------------------
+  lsrkStep_DQJtimes:
+
+  This routine generates a difference quotient approximation to
+  the Jacobian-vector product f_y(t,y) * v. The approximation is
+  Jv = [f(y + v*sig) - f(y)]/sig, where sig = 1 / ||v||_WRMS,
+  i.e. the WRMS norm of v*sig is 1.
+  ---------------------------------------------------------------*/
+int lsrkStep_DQJtimes(void* arkode_mem, N_Vector v, N_Vector Jv)
+{
+  ARKodeMem ark_mem;
+  ARKodeLSRKStepMem step_mem;
+
+  sunrealtype sig, siginv;
+  int iter, retval;
+
+  /* access ARKodeLSRKStepMem structure */
+  retval = lsrkStep_AccessARKODEStepMem(arkode_mem, __func__, &ark_mem,
+                                        &step_mem);
+  if (retval != ARK_SUCCESS) { return retval; }
+
+  sunrealtype t = ark_mem->tn;
+  N_Vector y    = ark_mem->yn;
+  N_Vector work = ark_mem->tempv3;
+
+  /* Compute RHS function, if necessary. */
+  if ((!ark_mem->fn_is_current && ark_mem->initsetup) ||
+      (step_mem->step_nst != ark_mem->nst))
+  {
+    retval = step_mem->fe(ark_mem->tn, ark_mem->yn, ark_mem->fn,
+                          ark_mem->user_data);
+    step_mem->nfeDQ++;
+    if (retval != ARK_SUCCESS)
+    {
+      SUNLogExtraDebugVec(ARK_LOGGER, "DomEig JvTimes RHS", ark_mem->fn,
+                          "F_n(:) =");
+      SUNLogInfo(ARK_LOGGER, "DomEig JvTimes",
+                 "status = failed rhs eval, retval = %i", retval);
+      return (ARK_RHSFUNC_FAIL);
+    }
+    ark_mem->fn_is_current = SUNTRUE;
+  }
+
+  /* Initialize perturbation to 1/||v|| */
+  sig = ONE / N_VWrmsNorm(v, ark_mem->ewt);
+
+  for (iter = 0; iter < MAX_DQITERS; iter++)
+  {
+    /* Set work = y + sig*v */
+    N_VLinearSum(sig, v, ONE, y, work);
+
+    /* Set Jv = f(tn, y+sig*v) */
+    //TODO:Needs to be update when LSRK Supports IMEX
+    retval = step_mem->fe(t, work, Jv, ark_mem->user_data);
+    step_mem->nfeDQ++;
+    if (retval == 0) { break; }
+    if (retval < 0) { return (-1); }
+
+    /* If f failed recoverably, shrink sig and retry */
+    sig *= SUN_RCONST(0.25);
+  }
+
+  /* If retval still isn't 0, return with a recoverable failure */
+  if (retval > 0) { return (+1); }
+
+  /* Replace Jv by (Jv - fn)/sig */
+  siginv = ONE / sig;
+  N_VLinearSum(siginv, Jv, -siginv, ark_mem->fn, Jv);
+
+  return ARK_SUCCESS;
+}
+
 /*===============================================================
   EOF
   ===============================================================*/
