@@ -1,9 +1,12 @@
 /*---------------------------------------------------------------
- * Programmer(s): Daniel R. Reynolds @ SMU
+ * Programmer(s): Daniel R. Reynolds @ UMBC
  *---------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2025, Lawrence Livermore National Security
+ * Copyright (c) 2025, Lawrence Livermore National Security,
+ * University of Maryland Baltimore County, and the SUNDIALS contributors.
+ * Copyright (c) 2013-2025, Lawrence Livermore National Security
  * and Southern Methodist University.
+ * Copyright (c) 2002-2013, Lawrence Livermore National Security.
  * All rights reserved.
  *
  * See the top-level LICENSE and NOTICE files for details.
@@ -782,7 +785,7 @@ int arkRootfind(void* arkode_mem)
     }
     else
     {
-      if ((DIFFERENT_SIGN(rootmem->glo[i], rootmem->ghi[i])) &&
+      if ((SUNRdifferentsign(rootmem->glo[i], rootmem->ghi[i])) &&
           (rootmem->rootdir[i] * rootmem->glo[i] <= ZERO))
       {
         gfrac = SUNRabs(rootmem->ghi[i] / (rootmem->ghi[i] - rootmem->glo[i]));
@@ -881,7 +884,7 @@ int arkRootfind(void* arkode_mem)
       }
       else
       {
-        if ((DIFFERENT_SIGN(rootmem->glo[i], rootmem->grout[i])) &&
+        if ((SUNRdifferentsign(rootmem->glo[i], rootmem->grout[i])) &&
             (rootmem->rootdir[i] * rootmem->glo[i] <= ZERO))
         {
           gfrac =
@@ -945,7 +948,7 @@ int arkRootfind(void* arkode_mem)
     {
       rootmem->iroots[i] = rootmem->glo[i] > 0 ? -1 : 1;
     }
-    if ((DIFFERENT_SIGN(rootmem->glo[i], rootmem->ghi[i])) &&
+    if ((SUNRdifferentsign(rootmem->glo[i], rootmem->ghi[i])) &&
         (rootmem->rootdir[i] * rootmem->glo[i] <= ZERO))
     {
       rootmem->iroots[i] = rootmem->glo[i] > 0 ? -1 : 1;
