@@ -1,9 +1,12 @@
 /* -----------------------------------------------------------------
- * Programmer(s): Daniel R. Reynolds @ SMU
+ * Programmer(s): Daniel R. Reynolds @ UMBC
  * -----------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2024, Lawrence Livermore National Security
+ * Copyright (c) 2025, Lawrence Livermore National Security,
+ * University of Maryland Baltimore County, and the SUNDIALS contributors.
+ * Copyright (c) 2013-2025, Lawrence Livermore National Security
  * and Southern Methodist University.
+ * Copyright (c) 2002-2013, Lawrence Livermore National Security.
  * All rights reserved.
  *
  * See the top-level LICENSE and NOTICE files for details.
@@ -39,7 +42,7 @@
 
 /* -----------------------------------------------------------------
  * Function to create a new ARKUserControl controller
- */
+ * ----------------------------------------------------------------- */
 
 SUNAdaptController ARKUserControl(SUNContext sunctx, void* arkode_mem,
                                   ARKAdaptFn hadapt, void* hadapt_data)
@@ -96,15 +99,14 @@ SUNAdaptController ARKUserControl(SUNContext sunctx, void* arkode_mem,
  * ----------------------------------------------------------------- */
 
 SUNAdaptController_Type SUNAdaptController_GetType_ARKUserControl(
-  SUNAdaptController C)
+  SUNDIALS_MAYBE_UNUSED SUNAdaptController C)
 {
   return SUN_ADAPTCONTROLLER_H;
 }
 
-SUNErrCode SUNAdaptController_EstimateStep_ARKUserControl(SUNAdaptController C,
-                                                          sunrealtype h, int p,
-                                                          sunrealtype dsm,
-                                                          sunrealtype* hnew)
+SUNErrCode SUNAdaptController_EstimateStep_ARKUserControl(
+  SUNAdaptController C, sunrealtype h, SUNDIALS_MAYBE_UNUSED int p,
+  sunrealtype dsm, sunrealtype* hnew)
 {
   /* call user-provided function to compute new step */
   sunrealtype ttmp = (dsm <= ONE) ? SC_ARKMEM(C)->tn + SC_ARKMEM(C)->h
@@ -129,17 +131,10 @@ SUNErrCode SUNAdaptController_Write_ARKUserControl(SUNAdaptController C,
                                                    FILE* fptr)
 {
   fprintf(fptr, "ARKUserControl module:\n");
-#if defined(SUNDIALS_EXTENDED_PRECISION)
-  fprintf(fptr, "  hp = %12Lg\n", SC_HP(C));
-  fprintf(fptr, "  hpp = %12Lg\n", SC_HPP(C));
-  fprintf(fptr, "  ep = %12Lg\n", SC_EP(C));
-  fprintf(fptr, "  epp = %12Lg\n", SC_EPP(C));
-#else
-  fprintf(fptr, "  hp = %12g\n", SC_HP(C));
-  fprintf(fptr, "  hpp = %12g\n", SC_HPP(C));
-  fprintf(fptr, "  ep = %12g\n", SC_EP(C));
-  fprintf(fptr, "  epp = %12g\n", SC_EPP(C));
-#endif
+  fprintf(fptr, "  hp = " SUN_FORMAT_G "\n", SC_HP(C));
+  fprintf(fptr, "  hpp = " SUN_FORMAT_G "\n", SC_HPP(C));
+  fprintf(fptr, "  ep = " SUN_FORMAT_G "\n", SC_EP(C));
+  fprintf(fptr, "  epp = " SUN_FORMAT_G "\n", SC_EPP(C));
   fprintf(fptr, "  hadapt_data = %p\n", SC_DATA(C));
   return SUN_SUCCESS;
 }
@@ -155,9 +150,8 @@ SUNErrCode SUNAdaptController_UpdateH_ARKUserControl(SUNAdaptController C,
   return SUN_SUCCESS;
 }
 
-SUNErrCode SUNAdaptController_Space_ARKUserControl(SUNAdaptController C,
-                                                   long int* lenrw,
-                                                   long int* leniw)
+SUNErrCode SUNAdaptController_Space_ARKUserControl(
+  SUNDIALS_MAYBE_UNUSED SUNAdaptController C, long int* lenrw, long int* leniw)
 {
   *lenrw = 4;
   *leniw = 2;
