@@ -2,8 +2,11 @@
  * Programmer(s): Radu Serban @ LLNL
  * -----------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2025, Lawrence Livermore National Security
+ * Copyright (c) 2025, Lawrence Livermore National Security,
+ * University of Maryland Baltimore County, and the SUNDIALS contributors.
+ * Copyright (c) 2013-2025, Lawrence Livermore National Security
  * and Southern Methodist University.
+ * Copyright (c) 2002-2013, Lawrence Livermore National Security.
  * All rights reserved.
  *
  * See the top-level LICENSE and NOTICE files for details.
@@ -1107,19 +1110,19 @@ int IDASensResDQ(int Ns, sunrealtype t, N_Vector yy, N_Vector yp,
   ". tout too far back in direction of integration."
 
 #define MSG_ERR_FAILS \
-  "At " MSG_TIME_H "the error test failed repeatedly or with |h| = hmin."
+  "At " MSG_TIME_H ", the error test failed repeatedly or with |h| = hmin."
 #define MSG_CONV_FAILS \
   "At " MSG_TIME_H     \
-  "the corrector convergence failed repeatedly or with |h| = hmin."
+  ", the corrector convergence failed repeatedly or with |h| = hmin."
 #define MSG_SETUP_FAILED \
-  "At " MSG_TIME "the linear solver setup failed unrecoverably."
+  "At " MSG_TIME ", the linear solver setup failed unrecoverably."
 #define MSG_SOLVE_FAILED \
-  "At " MSG_TIME "the linear solver solve failed unrecoverably."
-#define MSG_REP_RES_ERR "At " MSG_TIME "repeated recoverable residual errors."
+  "At " MSG_TIME ", the linear solver solve failed unrecoverably."
+#define MSG_REP_RES_ERR "At " MSG_TIME " repeated recoverable residual errors."
 #define MSG_RES_NONRECOV \
-  "At " MSG_TIME "the residual function failed unrecoverably."
+  "At " MSG_TIME ", the residual function failed unrecoverably."
 #define MSG_FAILED_CONSTR \
-  "At " MSG_TIME "unable to satisfy inequality constraints."
+  "At " MSG_TIME ", unable to satisfy inequality constraints."
 #define MSG_RTFUNC_FAILED                                                \
   "At " MSG_TIME ", the rootfinding routine failed in an unrecoverable " \
   "manner."
