@@ -1,13 +1,17 @@
 /*
  * -----------------------------------------------------------------
- * Programmer(s): Daniel Reynolds @ SMU
+ * Programmer(s): Daniel Reynolds @ UMBC
  *                David Gardner @ LLNL
+ *                Steven B. Roberts @ LLNL
  * Based on code sundials_sparse.c by: Carol Woodward and
- *     Slaven Peles @ LLNL, and Daniel R. Reynolds @ SMU
+ *     Slaven Peles @ LLNL, and Daniel R. Reynolds @ UMBC
  * -----------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2024, Lawrence Livermore National Security
+ * Copyright (c) 2025, Lawrence Livermore National Security,
+ * University of Maryland Baltimore County, and the SUNDIALS contributors.
+ * Copyright (c) 2013-2025, Lawrence Livermore National Security
  * and Southern Methodist University.
+ * Copyright (c) 2002-2013, Lawrence Livermore National Security.
  * All rights reserved.
  *
  * See the top-level LICENSE and NOTICE files for details.
@@ -22,13 +26,15 @@
 
 #include <stdio.h>
 #include <stdlib.h>
+
 #include <sundials/priv/sundials_errors_impl.h>
+#include <sundials/sundials_errors.h>
 #include <sundials/sundials_math.h>
 #include <sunmatrix/sunmatrix_band.h>
 #include <sunmatrix/sunmatrix_dense.h>
 #include <sunmatrix/sunmatrix_sparse.h>
 
-#include "sundials/sundials_errors.h"
+#include "sundials_macros.h"
 
 #define ZERO SUN_RCONST(0.0)
 #define ONE  SUN_RCONST(1.0)
@@ -39,6 +45,8 @@ static sunbooleantype compatibleMatrixAndVectors(SUNMatrix A, N_Vector x,
                                                  N_Vector y);
 static SUNErrCode Matvec_SparseCSC(SUNMatrix A, N_Vector x, N_Vector y);
 static SUNErrCode Matvec_SparseCSR(SUNMatrix A, N_Vector x, N_Vector y);
+static SUNErrCode MatTransposeVec_SparseCSC(SUNMatrix A, N_Vector x, N_Vector y);
+static SUNErrCode MatTransposeVec_SparseCSR(SUNMatrix A, N_Vector x, N_Vector y);
 static SUNErrCode format_convert(const SUNMatrix A, SUNMatrix B);
 
 /*
@@ -76,15 +84,16 @@ SUNMatrix SUNSparseMatrix(sunindextype M, sunindextype N, sunindextype NNZ,
   SUNCheckLastErrNull();
 
   /* Attach operations */
-  A->ops->getid     = SUNMatGetID_Sparse;
-  A->ops->clone     = SUNMatClone_Sparse;
-  A->ops->destroy   = SUNMatDestroy_Sparse;
-  A->ops->zero      = SUNMatZero_Sparse;
-  A->ops->copy      = SUNMatCopy_Sparse;
-  A->ops->scaleadd  = SUNMatScaleAdd_Sparse;
-  A->ops->scaleaddi = SUNMatScaleAddI_Sparse;
-  A->ops->matvec    = SUNMatMatvec_Sparse;
-  A->ops->space     = SUNMatSpace_Sparse;
+  A->ops->getid                    = SUNMatGetID_Sparse;
+  A->ops->clone                    = SUNMatClone_Sparse;
+  A->ops->destroy                  = SUNMatDestroy_Sparse;
+  A->ops->zero                     = SUNMatZero_Sparse;
+  A->ops->copy                     = SUNMatCopy_Sparse;
+  A->ops->scaleadd                 = SUNMatScaleAdd_Sparse;
+  A->ops->scaleaddi                = SUNMatScaleAddI_Sparse;
+  A->ops->matvec                   = SUNMatMatvec_Sparse;
+  A->ops->mathermitiantransposevec = SUNMatHermitianTransposeVec_Sparse;
+  A->ops->space                    = SUNMatSpace_Sparse;
 
   /* Create content */
   content = NULL;
@@ -387,21 +396,21 @@ void SUNSparseMatrix_Print(SUNMatrix A, FILE* outfile)
 {
   SUNFunctionBegin(A->sunctx);
   sunindextype i, j;
-  char* matrixtype;
-  char* indexname;
+  const char* matrixtype;
+  const char* indexname;
 
   SUNAssertVoid(SUNMatGetID(A) == SUNMATRIX_SPARSE, SUN_ERR_ARG_WRONGTYPE);
 
   /* perform operation */
   if (SM_SPARSETYPE_S(A) == CSC_MAT)
   {
-    indexname  = (char*)"col";
-    matrixtype = (char*)"CSC";
+    indexname  = "col";
+    matrixtype = "CSC";
   }
   else
   {
-    indexname  = (char*)"row";
-    matrixtype = (char*)"CSR";
+    indexname  = "row";
+    matrixtype = "CSR";
   }
   fprintf(outfile, "\n");
   fprintf(outfile, "%ld by %ld %s matrix, NNZ: %ld \n", (long int)SM_ROWS_S(A),
@@ -414,20 +423,11 @@ void SUNSparseMatrix_Print(SUNMatrix A, FILE* outfile)
     fprintf(outfile, "  ");
     for (i = (SM_INDEXPTRS_S(A))[j]; i < (SM_INDEXPTRS_S(A))[j + 1]; i++)
     {
-#if defined(SUNDIALS_EXTENDED_PRECISION)
-      fprintf(outfile, "%ld: %.32Lg   ", (long int)(SM_INDEXVALS_S(A))[i],
-              (SM_DATA_S(A))[i]);
-#elif defined(SUNDIALS_DOUBLE_PRECISION)
-      fprintf(outfile, "%ld: %.16g   ", (long int)(SM_INDEXVALS_S(A))[i],
-              (SM_DATA_S(A))[i]);
-#else
-      fprintf(outfile, "%ld: %.8g   ", (long int)(SM_INDEXVALS_S(A))[i],
-              (SM_DATA_S(A))[i]);
-#endif
+      fprintf(outfile, "%ld: " SUN_FORMAT_E "  ",
+              (long int)(SM_INDEXVALS_S(A))[i], (SM_DATA_S(A))[i]);
     }
     fprintf(outfile, "\n");
   }
-  fprintf(outfile, "\n");
   return;
 }
 
@@ -497,7 +497,10 @@ sunindextype* SUNSparseMatrix_IndexPointers(SUNMatrix A)
  * -----------------------------------------------------------------
  */
 
-SUNMatrix_ID SUNMatGetID_Sparse(SUNMatrix A) { return SUNMATRIX_SPARSE; }
+SUNMatrix_ID SUNMatGetID_Sparse(SUNDIALS_MAYBE_UNUSED SUNMatrix A)
+{
+  return SUNMATRIX_SPARSE;
+}
 
 SUNMatrix SUNMatClone_Sparse(SUNMatrix A)
 {
@@ -618,234 +621,72 @@ SUNErrCode SUNMatCopy_Sparse(SUNMatrix A, SUNMatrix B)
 
 SUNErrCode SUNMatScaleAddI_Sparse(sunrealtype c, SUNMatrix A)
 {
-  sunindextype j, i, p, nz, newvals, M, N, cend, nw;
-  sunbooleantype newmat, found;
-  sunindextype *w, *Ap, *Ai, *Cp, *Ci;
-  sunrealtype *x, *Ax, *Cx;
-  SUNMatrix C;
   SUNFunctionBegin(A->sunctx);
+  const sunindextype N = SM_SPARSETYPE_S(A) == CSC_MAT ? SM_COLUMNS_S(A)
+                                                       : SM_ROWS_S(A);
+  const sunindextype M = SM_SPARSETYPE_S(A) == CSC_MAT ? SM_ROWS_S(A)
+                                                       : SM_COLUMNS_S(A);
 
-  /* store shortcuts to matrix dimensions (M is inner dimension, N is outer) */
-  if (SM_SPARSETYPE_S(A) == CSC_MAT)
-  {
-    M = SM_ROWS_S(A);
-    N = SM_COLUMNS_S(A);
-  }
-  else
-  {
-    M = SM_COLUMNS_S(A);
-    N = SM_ROWS_S(A);
-  }
-
-  /* access data arrays from A */
-  Ap = NULL;
-  Ai = NULL;
-  Ax = NULL;
-  Ap = SM_INDEXPTRS_S(A);
+  sunindextype* Ap = SM_INDEXPTRS_S(A);
   SUNAssert(Ap, SUN_ERR_ARG_CORRUPT);
-  Ai = SM_INDEXVALS_S(A);
+  sunindextype* Ai = SM_INDEXVALS_S(A);
   SUNAssert(Ai, SUN_ERR_ARG_CORRUPT);
-  Ax = SM_DATA_S(A);
+  sunrealtype* Ax = SM_DATA_S(A);
   SUNAssert(Ax, SUN_ERR_ARG_CORRUPT);
 
-  /* determine if A: contains values on the diagonal (so I can just be added
-     in); if not, then increment counter for extra storage that should be
-     required. */
-  newvals = 0;
-  for (j = 0; j < SUNMIN(M, N); j++)
+  sunindextype newvals = 0;
+  for (sunindextype j = 0; j < N; j++)
   {
     /* scan column (row if CSR) of A, searching for diagonal value */
-    found = SUNFALSE;
-    for (i = Ap[j]; i < Ap[j + 1]; i++)
+    sunbooleantype found = SUNFALSE;
+    for (sunindextype i = Ap[j]; i < Ap[j + 1]; i++)
     {
       if (Ai[i] == j)
       {
         found = SUNTRUE;
-        break;
+        Ax[i] = ONE + c * Ax[i];
       }
+      else { Ax[i] *= c; }
     }
-    /* if no diagonal found, increment necessary storage counter */
-    if (!found) { newvals += 1; }
+    /* If no diagonal element found and the current column (row) can actually
+     * contain a diagonal element, increment the storage counter */
+    if (!found && j < M) { newvals++; }
   }
 
-  /* If extra nonzeros required, check whether matrix has sufficient storage
-     space for new nonzero entries  (so I can be inserted into existing storage)
-   */
-  newmat = SUNFALSE; /* no reallocation needed */
-  if (newvals > (SM_NNZ_S(A) - Ap[N])) { newmat = SUNTRUE; }
-
-  /* perform operation based on existing/necessary structure */
-
-  /*   case 1: A already contains a diagonal */
-  if (newvals == 0)
+  /* At this point, A has the correctly updated values except for any new
+   * diagonal elements that need to be added (of which there are newvals). Now,
+   * we allocate additional storage if needed */
+  const sunindextype new_nnz = Ap[N] + newvals;
+  if (new_nnz > SM_NNZ_S(A))
   {
-    /* iterate through columns, adding 1.0 to diagonal */
-    for (j = 0; j < SUNMIN(M, N); j++)
-    {
-      for (i = Ap[j]; i < Ap[j + 1]; i++)
-      {
-        if (Ai[i] == j) { Ax[i] = ONE + c * Ax[i]; }
-        else { Ax[i] = c * Ax[i]; }
-      }
-    }
-
-    /*   case 2: A has sufficient storage, but does not already contain a
-     * diagonal */
+    SUNCheckCall(SUNSparseMatrix_Reallocate(A, new_nnz));
+    Ap = SM_INDEXPTRS_S(A);
+    Ai = SM_INDEXVALS_S(A);
+    Ax = SM_DATA_S(A);
   }
-  else if (!newmat)
+
+  for (sunindextype j = N - 1; newvals > 0; j--)
   {
-    /* create work arrays for nonzero row (column) indices and values in a
-     * single column (row) */
-    w = (sunindextype*)malloc(M * sizeof(sunindextype));
-    SUNAssert(w, SUN_ERR_MALLOC_FAIL);
-    x = (sunrealtype*)malloc(M * sizeof(sunrealtype));
-    SUNAssert(x, SUN_ERR_MALLOC_FAIL);
-
-    /* determine storage location where last column (row) should end */
-    nz = Ap[N] + newvals;
-
-    /* store pointer past last column (row) from original A,
-       and store updated value in revised A */
-    cend  = Ap[N];
-    Ap[N] = nz;
-
-    /* iterate through columns (rows) backwards */
-    for (j = N - 1; j >= 0; j--)
+    sunbooleantype found = SUNFALSE;
+    for (sunindextype i = Ap[j + 1] - 1; i >= Ap[j]; i--)
     {
-      /* reset diagonal entry, in case it's not in A */
-      x[j] = ZERO;
+      if (Ai[i] == j) { found = SUNTRUE; }
 
-      /* iterate down column (row) of A, collecting nonzeros */
-      for (p = Ap[j], i = 0; p < cend; p++, i++)
-      {
-        w[i]     = Ai[p];     /* collect row (column) index */
-        x[Ai[p]] = c * Ax[p]; /* collect/scale value */
-      }
-
-      /* NNZ in this column (row) */
-      nw = cend - Ap[j];
-
-      /* add identity to this column (row) */
-      if (j < M) { x[j] += ONE; /* update value */ }
-
-      /* fill entries of A with this column's (row's) data */
-      /* fill entries past diagonal */
-      for (i = nw - 1; i >= 0 && w[i] > j; i--)
-      {
-        Ai[--nz] = w[i];
-        Ax[nz]   = x[w[i]];
-      }
-      /* fill diagonal if applicable */
-      if (i < 0 /* empty or insert at front */ ||
-          w[i] != j /* insert behind front */)
-      {
-        Ai[--nz] = j;
-        Ax[nz]   = x[j];
-      }
-      /* fill entries before diagonal */
-      for (; i >= 0; i--)
-      {
-        Ai[--nz] = w[i];
-        Ax[nz]   = x[w[i]];
-      }
-
-      /* store ptr past this col (row) from orig A, update value for new A */
-      cend  = Ap[j];
-      Ap[j] = nz;
+      /* Shift elements to make room for diagonal elements */
+      Ai[i + newvals] = Ai[i];
+      Ax[i + newvals] = Ax[i];
     }
 
-    /* clean up */
-    free(w);
-    free(x);
-
-    /*   case 3: A must be reallocated with sufficient storage */
-  }
-  else
-  {
-    /* create work array for nonzero values in a single column (row) */
-    x = (sunrealtype*)malloc(M * sizeof(sunrealtype));
-
-    /* create new matrix for sum */
-    C = SUNSparseMatrix(SM_ROWS_S(A), SM_COLUMNS_S(A), Ap[N] + newvals,
-                        SM_SPARSETYPE_S(A), A->sunctx);
-    SUNCheckLastErr();
-
-    /* access data from CSR structures (return if failure) */
-    Cp = NULL;
-    Ci = NULL;
-    Cx = NULL;
-    Cp = SM_INDEXPTRS_S(C);
-    SUNAssert(Cp, SUN_ERR_ARG_CORRUPT);
-    Ci = SM_INDEXVALS_S(C);
-    SUNAssert(Ci, SUN_ERR_ARG_CORRUPT);
-    Cx = SM_DATA_S(C);
-    SUNAssert(Cx, SUN_ERR_ARG_CORRUPT);
-
-    /* initialize total nonzero count */
-    nz = 0;
-
-    /* iterate through columns (rows for CSR) */
-    for (j = 0; j < N; j++)
+    Ap[j + 1] += newvals;
+    if (!found && j < M)
     {
-      /* set current column (row) pointer to current # nonzeros */
-      Cp[j] = nz;
-
-      /* reset diagonal entry, in case it's not in A */
-      x[j] = ZERO;
-
-      /* iterate down column (along row) of A, collecting nonzeros */
-      for (p = Ap[j]; p < Ap[j + 1]; p++)
-      {
-        x[Ai[p]] = c * Ax[p]; /* collect/scale value */
-      }
-
-      /* add identity to this column (row) */
-      if (j < M) { x[j] += ONE; /* update value */ }
-
-      /* fill entries of C with this column's (row's) data */
-      /* fill entries before diagonal */
-      for (p = Ap[j]; p < Ap[j + 1] && Ai[p] < j; p++)
-      {
-        Ci[nz]   = Ai[p];
-        Cx[nz++] = x[Ai[p]];
-      }
-      /* fill diagonal if applicable */
-      if (p >= Ap[j + 1] /* empty or insert at end */ ||
-          Ai[p] != j /* insert before end */)
-      {
-        Ci[nz]   = j;
-        Cx[nz++] = x[j];
-      }
-      /* fill entries past diagonal */
-      for (; p < Ap[j + 1]; p++)
-      {
-        Ci[nz]   = Ai[p];
-        Cx[nz++] = x[Ai[p]];
-      }
+      /* This column (row) needs a diagonal element added */
+      newvals--;
+      Ai[Ap[j] + newvals] = j;
+      Ax[Ap[j] + newvals] = ONE;
     }
-
-    /* indicate end of data */
-    Cp[N] = nz;
-
-    /* update A's structure with C's values; nullify C's pointers */
-    SM_NNZ_S(A) = SM_NNZ_S(C);
-
-    if (SM_DATA_S(A)) { free(SM_DATA_S(A)); }
-    SM_DATA_S(A) = SM_DATA_S(C);
-    SM_DATA_S(C) = NULL;
-
-    if (SM_INDEXVALS_S(A)) { free(SM_INDEXVALS_S(A)); }
-    SM_INDEXVALS_S(A) = SM_INDEXVALS_S(C);
-    SM_INDEXVALS_S(C) = NULL;
-
-    if (SM_INDEXPTRS_S(A)) { free(SM_INDEXPTRS_S(A)); }
-    SM_INDEXPTRS_S(A) = SM_INDEXPTRS_S(C);
-    SM_INDEXPTRS_S(C) = NULL;
-
-    /* clean up */
-    SUNMatDestroy_Sparse(C);
-    free(x);
   }
+
   return SUN_SUCCESS;
 }
 
@@ -1099,6 +940,22 @@ SUNErrCode SUNMatMatvec_Sparse(SUNMatrix A, N_Vector x, N_Vector y)
   return SUN_SUCCESS;
 }
 
+SUNErrCode SUNMatHermitianTransposeVec_Sparse(SUNMatrix A, N_Vector x, N_Vector y)
+{
+  SUNFunctionBegin(A->sunctx);
+  SUNAssert(SUNMatGetID(A) == SUNMATRIX_SPARSE, SUN_ERR_ARG_WRONGTYPE);
+  SUNCheck(compatibleMatrixAndVectors(A, y, x), SUN_ERR_ARG_DIMSMISMATCH);
+
+  /* Perform operation */
+  if (SM_SPARSETYPE_S(A) == CSC_MAT)
+  {
+    SUNCheckCall(MatTransposeVec_SparseCSC(A, x, y));
+  }
+  else { SUNCheckCall(MatTransposeVec_SparseCSR(A, x, y)); }
+
+  return SUN_SUCCESS;
+}
+
 SUNErrCode SUNMatSpace_Sparse(SUNMatrix A, long int* lenrw, long int* leniw)
 {
   SUNFunctionBegin(A->sunctx);
@@ -1120,6 +977,7 @@ SUNErrCode SUNMatSpace_Sparse(SUNMatrix A, long int* lenrw, long int* leniw)
  * Function to check compatibility of two sparse SUNMatrix objects
  */
 
+SUNDIALS_MAYBE_UNUSED
 static sunbooleantype compatibleMatrices(SUNMatrix A, SUNMatrix B)
 {
   /* both matrices must have the same shape and sparsity type */
@@ -1138,6 +996,7 @@ static sunbooleantype compatibleMatrices(SUNMatrix A, SUNMatrix B)
  * N_Vectors (A*x = b)
  */
 
+SUNDIALS_MAYBE_UNUSED
 static sunbooleantype compatibleMatrixAndVectors(SUNMatrix A, N_Vector x,
                                                  N_Vector y)
 {
@@ -1187,7 +1046,7 @@ SUNErrCode Matvec_SparseCSC(SUNMatrix A, N_Vector x, N_Vector y)
   SUNCheckLastErr();
 
   /* initialize result */
-  for (i = 0; i < SM_ROWS_S(A); i++) { yd[i] = 0.0; }
+  for (i = 0; i < SM_ROWS_S(A); i++) { yd[i] = ZERO; }
 
   /* iterate through matrix columns */
   for (j = 0; j < SM_COLUMNS_S(A); j++)
@@ -1199,6 +1058,40 @@ SUNErrCode Matvec_SparseCSC(SUNMatrix A, N_Vector x, N_Vector y)
   return SUN_SUCCESS;
 }
 
+SUNErrCode MatTransposeVec_SparseCSC(SUNMatrix A, N_Vector x, N_Vector y)
+{
+  sunindextype i, j;
+  sunindextype *Ap, *Ai;
+  sunrealtype *Ax, *xd, *yd;
+  SUNFunctionBegin(A->sunctx);
+
+  /* access data from CSC structure (return if failure) */
+  Ap = SM_INDEXPTRS_S(A);
+  SUNAssert(Ap, SUN_ERR_ARG_CORRUPT);
+  Ai = SM_INDEXVALS_S(A);
+  SUNAssert(Ai, SUN_ERR_ARG_CORRUPT);
+  Ax = SM_DATA_S(A);
+  SUNAssert(Ax, SUN_ERR_ARG_CORRUPT);
+
+  /* access vector data (return if failure) */
+  xd = N_VGetArrayPointer(x);
+  SUNCheckLastErr();
+  yd = N_VGetArrayPointer(y);
+  SUNCheckLastErr();
+
+  /* initialize result vector */
+  for (i = 0; i < SM_COLUMNS_S(A); i++) { yd[i] = ZERO; }
+
+  /* iterate through matrix columns (rows of the transposed matrix) */
+  for (j = 0; j < SM_COLUMNS_S(A); j++)
+  {
+    /* iterate through non-zero elements in the current column */
+    for (i = Ap[j]; i < Ap[j + 1]; i++) { yd[j] += Ax[i] * xd[Ai[i]]; }
+  }
+
+  return SUN_SUCCESS;
+}
+
 /* -----------------------------------------------------------------
  * Computes y=A*x, where A is a CSR SUNMatrix_Sparse of dimension MxN, x is a
  * compatible N_Vector object of length N, and y is a compatible
@@ -1229,8 +1122,9 @@ SUNErrCode Matvec_SparseCSR(SUNMatrix A, N_Vector x, N_Vector y)
   SUNAssert(xd, SUN_ERR_ARG_CORRUPT);
   SUNAssert(yd, SUN_ERR_ARG_CORRUPT);
   SUNAssert(xd != yd, SUN_ERR_ARG_CORRUPT);
+
   /* initialize result */
-  for (i = 0; i < SM_ROWS_S(A); i++) { yd[i] = 0.0; }
+  for (i = 0; i < SM_ROWS_S(A); i++) { yd[i] = ZERO; }
 
   /* iterate through matrix rows */
   for (i = 0; i < SM_ROWS_S(A); i++)
@@ -1242,6 +1136,42 @@ SUNErrCode Matvec_SparseCSR(SUNMatrix A, N_Vector x, N_Vector y)
   return SUN_SUCCESS;
 }
 
+SUNErrCode MatTransposeVec_SparseCSR(SUNMatrix A, N_Vector x, N_Vector y)
+{
+  sunindextype i, j;
+  sunindextype *Ap, *Aj;
+  sunrealtype *Ax, *xd, *yd;
+  SUNFunctionBegin(A->sunctx);
+
+  /* access data from CSR structure (return if failure) */
+  Ap = SM_INDEXPTRS_S(A);
+  SUNAssert(Ap, SUN_ERR_ARG_CORRUPT);
+  Aj = SM_INDEXVALS_S(A);
+  SUNAssert(Aj, SUN_ERR_ARG_CORRUPT);
+  Ax = SM_DATA_S(A);
+  SUNAssert(Ax, SUN_ERR_ARG_CORRUPT);
+
+  /* access vector data (return if failure) */
+  xd = N_VGetArrayPointer(x);
+  SUNCheckLastErr();
+  yd = N_VGetArrayPointer(y);
+  SUNCheckLastErr();
+  SUNAssert(xd, SUN_ERR_ARG_CORRUPT);
+  SUNAssert(yd, SUN_ERR_ARG_CORRUPT);
+  SUNAssert(xd != yd, SUN_ERR_ARG_CORRUPT);
+
+  /* initialize result vector */
+  for (i = 0; i < SM_COLUMNS_S(A); i++) { yd[i] = ZERO; }
+
+  /* iterate over rows of the original matrix (columns of the transposed matrix) */
+  for (i = 0; i < SM_ROWS_S(A); i++)
+  {
+    for (j = Ap[i]; j < Ap[i + 1]; j++) { yd[Aj[j]] += Ax[j] * xd[i]; }
+  }
+
+  return SUN_SUCCESS;
+}
+
 /* -----------------------------------------------------------------
  * Copies A into a matrix B in the opposite format of A.
  * Returns 0 if successful, nonzero if unsuccessful.
@@ -1298,7 +1228,7 @@ SUNErrCode format_convert(const SUNMatrix A, SUNMatrix B)
     sunindextype jj;
     for (jj = Ap[row]; jj < Ap[row + 1]; jj++)
     {
-      sunindextype col  = Aj[jj];
+      col               = Aj[jj];
       sunindextype dest = Bp[col];
 
       Bi[dest] = row;
