@@ -2,8 +2,11 @@
  * Programmer(s): Cody J. Balos @ LLNL
  * -----------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2024, Lawrence Livermore National Security
+ * Copyright (c) 2025, Lawrence Livermore National Security,
+ * University of Maryland Baltimore County, and the SUNDIALS contributors.
+ * Copyright (c) 2013-2025, Lawrence Livermore National Security
  * and Southern Methodist University.
+ * Copyright (c) 2002-2013, Lawrence Livermore National Security.
  * All rights reserved.
  *
  * See the top-level LICENSE and NOTICE files for details.
@@ -189,6 +192,21 @@ SUNErrCode SUNMemoryHelper_Alloc_Hip(SUNMemoryHelper helper, SUNMemory* memptr,
   return SUN_SUCCESS;
 }
 
+SUNErrCode SUNMemoryHelper_AllocStrided_Hip(SUNMemoryHelper helper,
+                                            SUNMemory* memptr, size_t mem_size,
+                                            size_t stride,
+                                            SUNMemoryType mem_type, void* queue)
+{
+  SUNFunctionBegin(helper->sunctx);
+
+  SUNCheckCall(
+    SUNMemoryHelper_Alloc_Hip(helper, memptr, mem_size, mem_type, queue));
+
+  (*memptr)->stride = stride;
+
+  return SUN_SUCCESS;
+}
+
 SUNErrCode SUNMemoryHelper_Dealloc_Hip(SUNMemoryHelper helper, SUNMemory mem,
                                        void* queue)
 {
@@ -303,6 +321,7 @@ SUNErrCode SUNMemoryHelper_CopyAsync_Hip(SUNMemoryHelper helper, SUNMemory dst,
   hipStream_t stream = 0;
 
   if (queue != NULL) { stream = *((hipStream_t*)queue); }
+  else if (helper->queue != NULL) { stream = *((hipStream_t*)helper->queue); }
 
   switch (src->type)
   {
