@@ -2,8 +2,11 @@
  * Programmer(s): Cody J. Balos @ LLNL
  * -----------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2025, Lawrence Livermore National Security
+ * Copyright (c) 2025, Lawrence Livermore National Security,
+ * University of Maryland Baltimore County, and the SUNDIALS contributors.
+ * Copyright (c) 2013-2025, Lawrence Livermore National Security
  * and Southern Methodist University.
+ * Copyright (c) 2002-2013, Lawrence Livermore National Security.
  * All rights reserved.
  *
  * See the top-level LICENSE and NOTICE files for details.
@@ -77,7 +80,8 @@ SUNErrCode SUNMemoryHelper_Alloc_Sys(SUNMemoryHelper helper, SUNMemory* memptr,
 {
   SUNFunctionBegin(helper->sunctx);
 
-  SUNAssert(mem_type == SUNMEMTYPE_HOST, SUN_ERR_ARG_INCOMPATIBLE);
+  SUNAssert(mem_type == SUNMEMTYPE_HOST || mem_type == SUNMEMTYPE_UVM,
+            SUN_ERR_ARG_INCOMPATIBLE);
 
   SUNMemory mem = SUNMemoryNewEmpty(helper->sunctx);
   SUNCheckLastErr();
@@ -87,7 +91,7 @@ SUNErrCode SUNMemoryHelper_Alloc_Sys(SUNMemoryHelper helper, SUNMemory* memptr,
   mem->type  = mem_type;
   mem->bytes = mem_size;
 
-  if (mem_type == SUNMEMTYPE_HOST)
+  if (mem_type == SUNMEMTYPE_HOST || mem_type == SUNMEMTYPE_UVM)
   {
     mem->ptr = malloc(mem_size);
     SUNAssert(mem->ptr, SUN_ERR_MALLOC_FAIL);
@@ -124,11 +128,12 @@ SUNErrCode SUNMemoryHelper_Dealloc_Sys(SUNMemoryHelper helper, SUNMemory mem,
 
   if (mem == NULL) { return SUN_SUCCESS; }
 
-  SUNAssert(mem->type == SUNMEMTYPE_HOST, SUN_ERR_ARG_INCOMPATIBLE);
+  SUNAssert(mem->type == SUNMEMTYPE_HOST || mem->type == SUNMEMTYPE_UVM,
+            SUN_ERR_ARG_INCOMPATIBLE);
 
   if (mem->ptr != NULL && mem->own)
   {
-    if (mem->type == SUNMEMTYPE_HOST)
+    if (mem->type == SUNMEMTYPE_HOST || mem->type == SUNMEMTYPE_UVM)
     {
       SUNHELPER_CONTENT(helper)->num_deallocations++;
       SUNHELPER_CONTENT(helper)->bytes_allocated -= mem->bytes;
@@ -146,8 +151,10 @@ SUNErrCode SUNMemoryHelper_Copy_Sys(SUNMemoryHelper helper, SUNMemory dst,
                                     SUNDIALS_MAYBE_UNUSED void* queue)
 {
   SUNFunctionBegin(helper->sunctx);
-  SUNAssert(src->type == SUNMEMTYPE_HOST, SUN_ERR_ARG_INCOMPATIBLE);
-  SUNAssert(dst->type == SUNMEMTYPE_HOST, SUN_ERR_ARG_INCOMPATIBLE);
+  SUNAssert(src->type == SUNMEMTYPE_HOST || src->type == SUNMEMTYPE_UVM,
+            SUN_ERR_ARG_INCOMPATIBLE);
+  SUNAssert(dst->type == SUNMEMTYPE_HOST || dst->type == SUNMEMTYPE_UVM,
+            SUN_ERR_ARG_INCOMPATIBLE);
   memcpy(dst->ptr, src->ptr, memory_size);
   return SUN_SUCCESS;
 }
@@ -158,7 +165,8 @@ SUNErrCode SUNMemoryHelper_GetAllocStats_Sys(
   size_t* bytes_allocated, size_t* bytes_high_watermark)
 {
   SUNFunctionBegin(helper->sunctx);
-  SUNAssert(mem_type == SUNMEMTYPE_HOST, SUN_ERR_ARG_INCOMPATIBLE);
+  SUNAssert(mem_type == SUNMEMTYPE_HOST || mem_type == SUNMEMTYPE_UVM,
+            SUN_ERR_ARG_INCOMPATIBLE);
   *num_allocations      = SUNHELPER_CONTENT(helper)->num_allocations;
   *num_deallocations    = SUNHELPER_CONTENT(helper)->num_deallocations;
   *bytes_allocated      = SUNHELPER_CONTENT(helper)->bytes_allocated;
